/*
 * JOnAS: Java(TM) Open Application Server
 * Copyright (C) 1999 Bull S.A.
 * Contact: jonas-team@objectweb.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: MgmtServlet.java,v 1.13 2004/03/30 12:09:40 benoitf Exp $
 * --------------------------------------------------------------------------
 */

package org.objectweb.j2eemanagement.servlets;

//import java
import java.io.IOException;
import java.io.PrintWriter;
import java.util.List;
import java.util.Iterator;
import java.net.URL;

//import javax
import javax.naming.Context;
import javax.naming.InitialContext;
import javax.servlet.ServletConfig;
import javax.servlet.ServletException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.rmi.PortableRemoteObject;

// JMX
import javax.management.ObjectName;
import javax.management.NotificationListener;
import javax.management.InstanceNotFoundException;
import javax.management.ListenerNotFoundException;
import javax.management.MBeanException;
import javax.management.InstanceNotFoundException;
import javax.management.ReflectionException;
import javax.management.RuntimeOperationsException;

// J2EE management imports
import javax.management.j2ee.ManagementHome;
import javax.management.j2ee.Management;
import javax.management.j2ee.ListenerRegistration;

/**
 * This servlet is an example to show how to access the MEJB from a servlet.
 * @author JOnAS team
 * @author Adriana Danes
 * @author Michel-Ange Anton
 */
public class MgmtServlet extends HttpServlet {

// ---------------------------------------------------------- Constants

    public final static String APP_TITLE_LARGE =
        "J2EE Management sample with Servlet accessing the MEJB";
    public final static String APP_TITLE = "J2EE Management sample";

    public final static String PARAM_DOMAIN = "domainName";
    public final static String PARAM_VIEW = "view";

    public final static String VIEW_INIT = "init";
    public final static String VIEW_NOTIFICATIONS = "notifications";
    public final static String VIEW_OTHER = "other";

// ---------------------------------------------------------- Instances variables

    private int m_AccessCount = 0;
    public MyListener m_Listener = null;

// ---------------------------------------------------------- Public methods

    /**
     * Initialize the servlet.
     * @param p_Config See HttpServlet
     * @throws ServletException
     */
    public void init(ServletConfig p_Config)
        throws ServletException {
        super.init(p_Config);
        // Initialize variables
        m_AccessCount = 0;
        m_Listener = null;
    }

// ---------------------------------------------------------- Protected methods

    /**
     * Response to the GET request.
     * @param p_Request See HttpServlet
     * @param p_Response See HttpServlet
     * @throws IOException
     * @throws ServletException
     */
    protected void doGet(HttpServletRequest p_Request, HttpServletResponse p_Response)
        throws IOException, ServletException {
        dispatch(p_Request, p_Response);
    }

    /**
     * Response to the POST request.
     * @param p_Request See HttpServlet
     * @param p_Response See HttpServlet
     * @throws IOException
     * @throws ServletException
     */
    protected void doPost(HttpServletRequest p_Request, HttpServletResponse p_Response)
        throws IOException, ServletException {
        dispatch(p_Request, p_Response);
    }

    /**
     * Dispatch the response.
     * @param p_Request Request
     * @param p_Response Response
     * @throws IOException
     * @throws ServletException
     */
    protected void dispatch(HttpServletRequest p_Request, HttpServletResponse p_Response)
        throws IOException, ServletException {

        p_Response.setContentType("text/html");
        PrintWriter out = p_Response.getWriter();

        // Get parameters
        String sParamDomain = p_Request.getParameter(PARAM_DOMAIN);
        String sParamView = p_Request.getParameter(PARAM_VIEW);

        // Dispatching
        if ((sParamDomain == null) || (sParamDomain.length() == 0)) {
            doViewError("Parameter domain not found", p_Request, out);
        }
        else if ((sParamView == null) || (sParamView.length() == 0) || (VIEW_INIT.equals(sParamView) == true)) {
            doViewInit(sParamDomain, p_Request, out);
        }
        else if (VIEW_NOTIFICATIONS.equals(sParamView) == true) {
            doViewNotifications(sParamDomain, p_Request, out);
        }
        else if (VIEW_OTHER.equals(sParamView) == true) {
            doViewOther(sParamDomain, p_Request, out);
        }
        else {
            doViewError("Unknown View", p_Request, out);
        }

    }

    /**
     * Header.
     * @param p_Out Printer
     * @param p_Title Title to display
     * @param p_SubTitle Subtitle to display or null if not
     * @throws IOException
     * @throws ServletException
     */
    protected void printHeader(PrintWriter p_Out, String p_Title, String p_SubTitle)
        throws IOException, ServletException {

        p_Out.println("<html>");
        p_Out.println("<head>");
        p_Out.println("<title>" + p_Title);
        if (p_SubTitle != null) {
            p_Out.println(" - " + p_SubTitle);
        }
        p_Out.println("</title>");
        p_Out.println("</head>");
        p_Out.println("<body style=\"background : white; color : black;\">");
        printHeaderTitle(p_Out, p_Title, p_SubTitle);
    }

    /**
     * Header.
     * @param p_Out Printer
     * @param p_Title Title to display
     * @param p_SubTitle Subtitle to display or null if not
     * @throws IOException
     * @throws ServletException
     */
    protected void printHeaderAutoRefresh(PrintWriter p_Out, String p_Title, String p_SubTitle)
        throws IOException, ServletException {

        p_Out.println("<html>");
        p_Out.println("<head>");
        p_Out.println("<title>" + p_Title + "</title>");
        p_Out.println("<script language=\"JavaScript\">");
        p_Out.println("function startRefresh(){ setTimeout(\"refresh()\",30000); self.focus(); }");
        p_Out.println("function refresh(){ window.location.reload(); }");
        p_Out.println("</script>");
        p_Out.println("</head>");
        p_Out.println(
            "<body onload=\"startRefresh()\" style=\"background : white; color : black;\">");
        printHeaderTitle(p_Out, p_Title, p_SubTitle);
    }

    /**
     * Header title.
     * @param p_Out Printer
     * @param p_Title Title to display
     * @param p_SubTitle Subtitle to display or null if not
     * @throws IOException
     * @throws ServletException
     */
    protected void printHeaderTitle(PrintWriter p_Out, String p_Title, String p_SubTitle)
        throws IOException, ServletException {

        p_Out.println("<table width=\"100%\" border=\"0\">");
        p_Out.println("<tr>");
        p_Out.println("<td rowspan=\"2\"><img src=\"img/logo_jonas.jpg\" alt=\"JOnAS Logo\"></td>");
        p_Out.println("<td align=\"center\"><h1>" + p_Title + "</h1></td>");
        p_Out.println("</tr>");
        p_Out.println("<tr>");
        if (p_SubTitle != null) {
            p_Out.println("<td align=\"center\"><h1>" + p_SubTitle + "</h1></td>");
        }
        p_Out.println("</tr>");
        p_Out.println("</table>");
    }

    /**
     * Footer.
     * @param p_Out Printer
     * @throws IOException
     * @throws ServletException
     */
    protected void printFooter(PrintWriter p_Out)
        throws IOException {

        p_Out.println("</body>");
        p_Out.println("</html>");
    }

    /**
     * Footer navigation.
     * @param p_DomainName Name of domain
     * @param p_Request Http request
     * @param p_Out Printer
     * @param p_Previous Previous view
     * @param p_Next Next view
     * @throws IOException
     */
    protected void printNavigationFooter(String p_DomainName, HttpServletRequest p_Request
        , PrintWriter p_Out, String p_Previous, String p_Next)
        throws IOException {

        // index
        String sViewIndex = p_Request.getContextPath();
        // Notifications
        String sViewNotifications = p_Request.getRequestURI() + "?" + PARAM_DOMAIN + "="
            + p_DomainName + "&" + PARAM_VIEW + "=" + VIEW_NOTIFICATIONS;
        // Previous View
        String sPrevView = null;
        if (p_Previous != null) {
            sPrevView = p_Request.getRequestURI() + "?" + PARAM_DOMAIN + "=" + p_DomainName + "&"
                + PARAM_VIEW + "=" + p_Previous;
        }
        // Next View
        String sNextView = null;
        if (p_Next != null) {
            sNextView = p_Request.getRequestURI() + "?" + PARAM_DOMAIN + "=" + p_DomainName
                + "&" + PARAM_VIEW + "=" + p_Next;
        }

        // Display
        p_Out.print("<table border=\"1\" align=\"center\" cellspacing=\"0\" cellpadding=\"5\">");
        p_Out.print("<tr>");
        p_Out.print("<td align=\"center\"> <a href=\"" + sViewIndex + "\">Index</a> </td>");
        p_Out.print("<td align=\"center\"> <a href=\"" + sViewNotifications
            + "\" target=\"ViewNotifications\">Notifications</a> </td>");
        if (sPrevView != null) {
            p_Out.println("<td align=\"center\"> <a href=\"" + sPrevView + "\">Previous</a> </td>");
        }
        if (sNextView != null) {
            p_Out.println("<td align=\"center\"> <a href=\"" + sNextView + "\">Next</a> </td>");
        }
        p_Out.println("</tr></table>");
        // Footer
        printFooter(p_Out);
    }

    /**
     * Simply View error.
     * @param p_Error Message error
     * @param p_Request Http request
     * @param p_Out Printer
     * @throws IOException
     * @throws ServletException
     */
    protected void doViewError(String p_Error, HttpServletRequest p_Request, PrintWriter p_Out)
        throws IOException, ServletException {

        // Header
        printHeader(p_Out, APP_TITLE, "Error");
        // Error message
        p_Out.println("<h2>" + p_Error + "</h2>");
        // Return
        p_Out.println("<a href=\"" + p_Request.getContextPath() + "\">Return</a>");
        // Footer
        printFooter(p_Out);
    }

    /**
     * View init MEJB and access to MBEans J2EEDomain and J2EEServer.
     * @param p_DomainName Name of domain to access
     * @param p_Request Http request
     * @param p_Out Printer
     * @throws IOException
     * @throws ServletException
     */
    protected void doViewInit(String p_DomainName, HttpServletRequest p_Request, PrintWriter p_Out)
        throws IOException, ServletException {

        // Header
        printHeader(p_Out, APP_TITLE_LARGE, "Init");

        // -----------------------------
        // Get initial context
        // -----------------------------

        p_Out.println("<h2>Initial context</h2>");
        p_Out.println("<ul>");
        Context initialContext = null;
        try {
            initialContext = new InitialContext();
            p_Out.println("<li>Initial context OK</li>");
        }
        catch (Exception e) {
            p_Out.print("<li>Cannot get initial context for JNDI: ");
            p_Out.println(e + "</li>");
            p_Out.println("</ul>");
            return;
        }
        p_Out.println("</ul><br>");

        // -----------------------------
        // Access to MEJB
        // -----------------------------

        p_Out.println("<h2>Create MEJB</h2>");
        p_Out.println("<ul>");

        // Connecting to the MEJB home through JNDI
        ManagementHome mgmtHome = null;
        try {
            mgmtHome = (ManagementHome) PortableRemoteObject.narrow(initialContext.lookup(
                "java:comp/env/ejb/MEJB"), ManagementHome.class);
        }
        catch (Exception e) {
            p_Out.println("<li>Cannot lookup java:comp/env/ejb/MEJB: " + e + "</li>");
            p_Out.println("</ul>");
            return;
        }
        // Management bean creation
        Management mgmt = null;
        try {
            mgmt = mgmtHome.create();
            p_Out.println("<li>MEJB created</li>");
        }
        catch (Exception e) {
            p_Out.println("<li>Cannot create MEJB: " + e + "</li>");
            return;
        }
        p_Out.println("</ul><br />");

        // ------------------------------
        // Access to the J2EEDomain MBean
        // ------------------------------

        p_Out.println("<h2>Access the J2EEDomain MBean</h2>");
        p_Out.println("<ul>");

        // MBean J2EEDomain
        ObjectName onDomain = null;
        try {
            String name = p_DomainName + ":j2eeType=J2EEDomain,name=" + p_DomainName;
            onDomain = new ObjectName(name);
            if (onDomain != null) {
                p_Out.println("<li>J2EEDomain Object Name: \"" + name.toString() + "\" created</li>");
            }
            else {
                throw new Exception("Domain not found");
            }
        }
        catch (Exception e) {
            p_Out.println("<li>Cannot create object name for J2EEDomain managed object: " + e
                + "</li>");
            p_Out.println("</ul>");
            return;
        }

        // A J2EEServer MBean
        ObjectName onServer = null;
        List listServers = null;
        try {
            boolean exists = mgmt.isRegistered(onDomain);
            if (exists) {
                p_Out.println(
                    "<li>This J2EEDomain managed object is registered in the current MBean server</li>");

                // Look for J2EEServer MBeans in the domain
                listServers = (List) mgmt.getAttribute(onDomain, "Servers");
                if (listServers.isEmpty() == true) {
                    p_Out.println(
                    "<li>No J2EE servers running in this domain.</li>");
                } else {
                    p_Out.println(
                                  "<li>List of J2EE servers running in this domain (list of the associated MBeans):</li>");
                    p_Out.println("<ol>");

                    Iterator it = listServers.iterator();
                    while (it.hasNext()) {
                        String sServer = (String) it.next();
                        ObjectName on = new ObjectName(sServer);
                        if (mgmt.isRegistered(on)) {
                            p_Out.print("<li>The MBean having object name \"" + sServer);
                            p_Out.println("\" is registered in the MBean server.");
                            p_Out.println("</li>");
                        }
                        else {
                            p_Out.print("<li>Found MBean object name \"" + sServer);
                            p_Out.println("\" in the severs list, but this name is not registered in the MBean server.");
                            p_Out.println("</li>");
                        }
                        onServer = on;
                    }
                    p_Out.println("</ol>");
                }
            }
            else {
                p_Out.println("<li><b>Can't find the J2EEDomain managed object having the above name in the current MBean server</b></li>");
                return;
            }
        }
        catch (Exception e) {
            p_Out.println("<li>Error when using the J2EEDomain managed object: " + e + "</li>");
            p_Out.println("</ul>");
            return;
        }
        p_Out.println("</ul><br>");
    
        // ------------------------------
        // Access to a J2EEServer MBean
        // ------------------------------
        if ((onServer != null) && mgmt.isRegistered(onServer)) {
            p_Out.println("<h2>Access a J2EEServer MBean</h2>");
            p_Out.println("<ul>");

            p_Out.println("<li>Using the J2EEServer Object Name: \"" + onServer.toString() + "\"</li>");
            p_Out.println("<li>Try to deploy sb.jar !</li>");
            String[] signature = { "java.lang.String" };
            String[] params = new String[1];
            params[0] = "sb.jar";
            try {
                String deployed_on = (String) mgmt.invoke(onServer, "deployJar", params, signature);
                p_Out.println("<li>The Object Name of the deployed J2EEModule is: \"" + deployed_on + "\". </li>");
            } catch (MBeanException e) {
                p_Out.println("<li>Could not deploy sb.jar because of exception: " + e.getTargetException().toString() + " </li>");
                p_Out.println("<li>Then, try to undeploy sb.jar...</li>");
                try {
                    mgmt.invoke(onServer, "unDeployJar", params, signature);
                    p_Out.println("<li>Done.</li>");
                } catch (Exception ex) {
                    p_Out.println("<li>Could not undeploy sb.ear");
                }
            } catch (InstanceNotFoundException e) {
                p_Out.println("<li>Could not deploy sb.jar because of exception: " + e.toString() + " </li>");
            } catch (ReflectionException e) {
                p_Out.println("<li>Could not deploy sb.jar because of exception: " + e.getTargetException().toString() + " </li>");
            }


            p_Out.println("<li>Try to deploy earsample.jar!</li>");
            params[0] = "earsample.ear";
            try {
                String deployed_on = (String) mgmt.invoke(onServer, "deployEar", params, signature);
                p_Out.println("<li>The Object Name of the deployed J2EEApplication is: \"" + deployed_on + "\". </li>");
            } catch (MBeanException e) {
                p_Out.println("<li>Could not deploy earsample.ear because of exception: " + e.getTargetException().toString() + " </li>");
                p_Out.println("<li>Then, try to undeploy earsample.jar...</li>");
                try {
                    mgmt.invoke(onServer, "unDeployEar", params, signature);
                    p_Out.println("<li>Done.</li>");
                } catch (Exception ex) {
                    p_Out.println("<li>Could not undeploy earsample.ear");
                }
            } catch (InstanceNotFoundException e) {
                p_Out.println("<li>Could not deploy earsample.ear because of exception: " + e.toString() + " </li>");
            } catch (ReflectionException e) {
                p_Out.println("<li>Could not deploy earsample.ear because of exception: " + e.getTargetException().toString() + " </li>");
            }

            p_Out.println("</ul><br>");
        }

        // -----------------------------
        // Test Event Listener support
        // -----------------------------

        p_Out.println("<h2>Register a event listener</h2>");
        p_Out.println("<ul>");
        if (m_Listener == null) {
            m_Listener = new MyListener();
            p_Out.println("<li>MyListener created</li>");
        }

        // Get the ListenerRegistration object
        ListenerRegistration lr = mgmt.getListenerRegistry();
        try {
            p_Out.println("<li>Add listener on J2EEServer (" + onServer.toString() + ")</li>");
            String sHandler = "MEJBTester" + String.valueOf(m_AccessCount);
            lr.addNotificationListener(onServer, m_Listener, null, sHandler);
            m_AccessCount++;
            p_Out.println("<li>Notification Listener added</li>");
        }
        catch (InstanceNotFoundException e) {
            p_Out.println("<li>Can't add notification listener on " + onServer.toString() + " : "
                + e + "</li>");
        }
        String sViewNotifications = p_Request.getRequestURI() + "?" + PARAM_DOMAIN + "="
            + p_DomainName + "&" + PARAM_VIEW + "=" + VIEW_NOTIFICATIONS;
        p_Out.println("<a href=\"" + sViewNotifications
            + "\" target=\"ViewNotifications\">See list of notifications</a>");
        p_Out.println("</ul>");

        p_Out.println("<h2>View Sample Init is OK </h2>");

        // Footer
        printNavigationFooter(p_DomainName, p_Request, p_Out, null, VIEW_OTHER);
    }

    /**
     * View notifications.
     * @param p_DomainName Name of domain to access
     * @param p_Request Http request
     * @param p_Out Printer
     * @throws IOException
     * @throws ServletException
     */
    protected void doViewNotifications(String p_DomainName, HttpServletRequest p_Request
        , PrintWriter p_Out)
        throws IOException, ServletException {

        // Header
        printHeaderAutoRefresh(p_Out, APP_TITLE, "Notifications");
        p_Out.println("<h2>List of notifications</h2>");

        // Verify listener
        if (m_Listener == null) {
            p_Out.println("Listener not found !");
        }
        else {
            // Display notifications
            List list = m_Listener.getlistNotifications();
            if (list.size() > 0) {
                p_Out.println("<ol>");
                for (int i = 0; i < list.size(); i++) {
                    p_Out.println("<li>" + list.get(i) + "</li>");
                }
                p_Out.println("</ol>");
            }
            else {
                p_Out.println("No notifications, the list is empty");
            }
        }

        // Footer
        printFooter(p_Out);
    }

    /**
     * View example.
     * @param p_DomainName Name of domain to access
     * @param p_Request Http request
     * @param p_Out Printer
     * @throws IOException
     * @throws ServletException
     */
    protected void doViewOther(String p_DomainName, HttpServletRequest p_Request
        , PrintWriter p_Out)
        throws IOException, ServletException {

        // Header
        printHeader(p_Out, APP_TITLE, "Other");

        p_Out.println("<h2>Other</h2>");

        // Footer
        printNavigationFooter(p_DomainName, p_Request, p_Out, VIEW_INIT, null);
    }
}
