/*
 * JOnAS: Java(TM) Open Application Server
 * Copyright (C) 1999 Bull S.A.
 * Contact: jonas-team@objectweb.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: J2eeObjectName.java,v 1.22 2004/03/29 09:16:39 danesa Exp $
 * --------------------------------------------------------------------------
 */

package org.objectweb.jonas.jmx;

import java.util.ArrayList;
import java.util.Collections;
import java.util.Iterator;
import java.util.List;
import javax.management.ObjectName;

/**
 * A set of static methods used to create object names for J2EE managed object.
 * This implementation is conformant to the JSR77.
 * @author Adriana Danes
 * Contributor(s): Michel-Ange Anton
 */
public class J2eeObjectName {

// --------------------------------------------------------- Constants

    public static final String ALL = "*";
    public static final String NONE = "none";

//  --------------------------------------------------------- Public Methods
    /**
     * @param p_ObjectName Stringified ObjectName
     * @return ObjectName instance corresponding to the received argument
     */
    public static ObjectName getObjectName(String p_ObjectName) {
    	try {
    		return ObjectName.getInstance(p_ObjectName);
    	} catch (javax.management.MalformedObjectNameException e) {
            // this should never occur
    		return null;
    	}
    }
    
    /**
     * Return the list of <code>ObjectName</code> gotten by the query
     * in the current MbeanServer.
     *
     * @param p_On Query Mbeans to search
     * @return The list of <code>ObjectName</code>
     * @throws ManagementException
     */
    public static List queryObjectNames(ObjectName p_On)
        throws ManagementException {
        ArrayList al = new ArrayList();
        Iterator itNames = JonasManagementRepr.queryNames(p_On).iterator();
        while (itNames.hasNext()) {
            al.add(itNames.next());
        }
        return al;
    }

    /**
     * Return the list of ObjectName's String gotten by the query in the current MbeanServer.
     *
     * @param p_On Query Mbeans to search
     * @return A list of <code>ObjectName</code> convert to String
     * @throws ManagementException
     */
    public static List queryStrings(ObjectName p_On)
        throws ManagementException {
        ArrayList al = new ArrayList();
        Iterator itNames = JonasManagementRepr.queryNames(p_On).iterator();
        while (itNames.hasNext()) {
            ObjectName item = (ObjectName) itNames.next();
            al.add(item.toString());
        }
        Collections.sort(al);
        return al;
    }

    public static ObjectName J2EEDomain(String p_Domain) {
        try {
            StringBuffer sb = new StringBuffer(p_Domain);
            sb.append(":j2eeType=J2EEDomain");
            sb.append(",name=");
            sb.append(p_Domain);
            return new ObjectName(sb.toString());
        }
        catch (javax.management.MalformedObjectNameException e) {
            // this should never occur
            return null;
        }
    }

    public static ObjectName J2EEDomains() {
        try {
            StringBuffer sb = new StringBuffer(ALL);
            sb.append(":j2eeType=J2EEDomain");
            sb.append(",");
            sb.append(ALL);
            return new ObjectName(sb.toString());
        }
        catch (javax.management.MalformedObjectNameException e) {
            // this should never occur
            return null;
        }
    }

    public static ObjectName J2EEServers() {
        try {
            StringBuffer sb = new StringBuffer(ALL);
            sb.append(":j2eeType=J2EEServer");
            sb.append(",");
            sb.append(ALL);
            return new ObjectName(sb.toString());
        }
        catch (javax.management.MalformedObjectNameException e) {
            // this should never occur
            return null;
        }
    }

    public static ObjectName J2EEServers(String p_Domain) {
        try {
            StringBuffer sb = new StringBuffer(p_Domain);
            sb.append(":j2eeType=J2EEServer");
            sb.append(",");
            sb.append(ALL);
            return new ObjectName(sb.toString());
        }
        catch (javax.management.MalformedObjectNameException e) {
            // this should never occur
            return null;
        }
    }

    public static ObjectName J2EEServer(String p_Domain, String p_Server) {
        try {
            StringBuffer sb = new StringBuffer(p_Domain);
            sb.append(":j2eeType=J2EEServer");
            sb.append(",name=");
            sb.append(p_Server);
            return new ObjectName(sb.toString());
        }
        catch (javax.management.MalformedObjectNameException e) {
            // this should never occur
            return null;
        }
    }

    public static ObjectName JVM(String p_Domain, String p_Server, String p_Name) {
        try {
            StringBuffer sb = new StringBuffer(p_Domain);
            sb.append(":j2eeType=JVM");
            sb.append(",name=");
            sb.append(p_Name);
            sb.append(",J2EEServer=");
            sb.append(p_Server);
            return new ObjectName(sb.toString());
        }
        catch (javax.management.MalformedObjectNameException e) {
            // this should never occur
            return null;
        }
    }

    public static ObjectName JVMs(String p_Domain, String p_Server) {
        try {
            StringBuffer sb = new StringBuffer(p_Domain);
            sb.append(":j2eeType=JVM");
            sb.append(",J2EEServer=");
            sb.append(p_Server);
            sb.append(",");
            sb.append(ALL);
            return new ObjectName(sb.toString());
        }
        catch (javax.management.MalformedObjectNameException e) {
            // this should never occur
            return null;
        }
    }

    public static ObjectName J2EEApplications() {
        try {
            StringBuffer sb = new StringBuffer(ALL);
            sb.append(":j2eeType=J2EEApplication");
            sb.append(",");
            sb.append(ALL);
            return new ObjectName(sb.toString());
        }
        catch (javax.management.MalformedObjectNameException e) {
            // this should never occur
            return null;
        }
    }

    public static ObjectName J2EEApplications(String p_Domain) {
        try {
            StringBuffer sb = new StringBuffer(p_Domain);
            sb.append(":j2eeType=J2EEApplication");
            sb.append(",");
            sb.append(ALL);
            return new ObjectName(sb.toString());
        }
        catch (javax.management.MalformedObjectNameException e) {
            // this should never occur
            return null;
        }
    }

    public static ObjectName J2EEApplications(String p_Domain, String p_Server) {
        try {
            StringBuffer sb = new StringBuffer(p_Domain);
            sb.append(":j2eeType=J2EEApplication");
            sb.append(",J2EEServer=");
            sb.append(p_Server);
            sb.append(",");
            sb.append(ALL);
            return new ObjectName(sb.toString());
        }
        catch (javax.management.MalformedObjectNameException e) {
            // this should never occur
            return null;
        }
    }

    public static ObjectName J2EEApplication(String p_Domain, String p_Server, String p_Name) {
        try {
            StringBuffer sb = new StringBuffer(p_Domain);
            sb.append(":j2eeType=J2EEApplication");
            sb.append(",name=");
            sb.append(p_Name);
            sb.append(",J2EEServer=");
            sb.append(p_Server);
            return new ObjectName(sb.toString());
        }
        catch (javax.management.MalformedObjectNameException e) {
            // this should never occur
            return null;
        }
    }

    public static ObjectName getAppClientModules(String p_Domain, String p_Server, String p_Application) {
        try {
            StringBuffer sb = new StringBuffer(p_Domain);
            sb.append(":j2eeType=AppClientModule");
            sb.append(",J2EEApplication=");
            if ((p_Application != null) && (p_Application.length() > 0)) {
                sb.append(p_Application);
            }
            else {
                sb.append(NONE);
            }
            sb.append(",J2EEServer=");
            sb.append(p_Server);
            sb.append(",");
            sb.append(ALL);
            return new ObjectName(sb.toString());
        }
        catch (javax.management.MalformedObjectNameException e) {
            // this should never occur
            return null;
        }
    }

    public static ObjectName getEJBModules() {
        try {
            StringBuffer sb = new StringBuffer(ALL);
            sb.append(":j2eeType=EJBModule");
            sb.append(",");
            sb.append(ALL);
            return new ObjectName(sb.toString());
        }
        catch (javax.management.MalformedObjectNameException e) {
            // this should never occur
            return null;
        }
    }

    public static ObjectName getEJBModules(String p_Domain) {
        try {
            StringBuffer sb = new StringBuffer(p_Domain);
            sb.append(":j2eeType=EJBModule");
            sb.append(",");
            sb.append(ALL);
            return new ObjectName(sb.toString());
        }
        catch (javax.management.MalformedObjectNameException e) {
            // this should never occur
            return null;
        }
    }

    public static ObjectName getEJBModules(String p_Domain, String p_Server) {
        try {
            StringBuffer sb = new StringBuffer(p_Domain);
            sb.append(":j2eeType=EJBModule");
            sb.append(",J2EEServer=");
            sb.append(p_Server);
            sb.append(",");
            sb.append(ALL);
            return new ObjectName(sb.toString());
        }
        catch (javax.management.MalformedObjectNameException e) {
            // this should never occur
            return null;
        }
    }

    public static ObjectName getEJBModules(String p_Domain, String p_Server, String p_Application) {
        try {
            StringBuffer sb = new StringBuffer(p_Domain);
            sb.append(":j2eeType=EJBModule");
            sb.append(",J2EEApplication=");
            if ((p_Application != null) && (p_Application.length() > 0)) {
                sb.append(p_Application);
            }
            else {
                sb.append(NONE);
            }
            sb.append(",J2EEServer=");
            sb.append(p_Server);
            sb.append(",");
            sb.append(ALL);
            return new ObjectName(sb.toString());
        }
        catch (javax.management.MalformedObjectNameException e) {
            // this should never occur
            return null;
        }
    }

    public static ObjectName getEJBModule(String p_Domain, String p_Server, String p_Application
        , String p_Name) {
        try {
            StringBuffer sb = new StringBuffer(p_Domain);
            sb.append(":j2eeType=EJBModule");
            sb.append(",name=");
            sb.append(p_Name);
            sb.append(",J2EEApplication=");
            if ((p_Application != null) && (p_Application.length() > 0)) {
                sb.append(p_Application);
            }
            else {
                sb.append(NONE);
            }
            sb.append(",J2EEServer=");
            sb.append(p_Server);
            return new ObjectName(sb.toString());
        }
        catch (javax.management.MalformedObjectNameException e) {
            // this should never occur
            return null;
        }
    }

    public static ObjectName getEntityBean(String p_Domain, String p_module, String p_Server, String p_Application
        , String p_Name) {
        try {
            StringBuffer sb = new StringBuffer(p_Domain);
            sb.append(":j2eeType=EntityBean");
            sb.append(",name=");
            sb.append(p_Name);
            sb.append(",EJBModule=");
            sb.append(p_module);
            sb.append(",J2EEApplication=");
            if ((p_Application != null) && (p_Application.length() > 0)) {
                sb.append(p_Application);
            }
            else {
                sb.append(NONE);
            }
            sb.append(",J2EEServer=");
            sb.append(p_Server);
            return new ObjectName(sb.toString());
        }
        catch (javax.management.MalformedObjectNameException e) {
            // this should never occur
            return null;
        }
    }

    public static ObjectName getEntityBeans(String p_Domain, String p_module) {
        try {
            StringBuffer sb = new StringBuffer(p_Domain);
            sb.append(":j2eeType=EntityBean");
            sb.append(",EJBModule=");
            sb.append(p_module);
            sb.append(",");
            sb.append(ALL);
            return new ObjectName(sb.toString());
        }
        catch (javax.management.MalformedObjectNameException e) {
            // this should never occur
            return null;
        }
    }

    public static ObjectName getEntityBeans(String p_Domain, String p_module, String p_Server) {
        try {
            StringBuffer sb = new StringBuffer(p_Domain);
            sb.append(":j2eeType=EntityBean");
            sb.append(",EJBModule=");
            sb.append(p_module);
            sb.append(",J2EEServer=");
            sb.append(p_Server);
            sb.append(",");
            sb.append(ALL);
            return new ObjectName(sb.toString());
        }
        catch (javax.management.MalformedObjectNameException e) {
            // this should never occur
            return null;
        }
    }

    public static ObjectName getStatefulSessionBean(String p_Domain, String p_module, String p_Server, String p_Application
        , String p_Name) {
        try {
            StringBuffer sb = new StringBuffer(p_Domain);
            sb.append(":j2eeType=StatefulSessionBean");
            sb.append(",name=");
            sb.append(p_Name);
            sb.append(",EJBModule=");
            sb.append(p_module);
            sb.append(",J2EEApplication=");
            if ((p_Application != null) && (p_Application.length() > 0)) {
                sb.append(p_Application);
            }
            else {
                sb.append(NONE);
            }
            sb.append(",J2EEServer=");
            sb.append(p_Server);
            return new ObjectName(sb.toString());
        }
        catch (javax.management.MalformedObjectNameException e) {
            // this should never occur
            return null;
        }
    }

    public static ObjectName getStatefulSessionBeans(String p_Domain, String p_module) {
        try {
            StringBuffer sb = new StringBuffer(p_Domain);
            sb.append(":j2eeType=StatefulSessionBean");
            sb.append(",EJBModule=");
            sb.append(p_module);
            sb.append(",");
            sb.append(ALL);
            return new ObjectName(sb.toString());
        }
        catch (javax.management.MalformedObjectNameException e) {
            // this should never occur
            return null;
        }
    }

    public static ObjectName getStatefulSessionBeans(String p_Domain, String p_module, String p_Server) {
        try {
            StringBuffer sb = new StringBuffer(p_Domain);
            sb.append(":j2eeType=StatefulSessionBean");
            sb.append(",EJBModule=");
            sb.append(p_module);
            sb.append(",J2EEServer=");
            sb.append(p_Server);
            sb.append(",");
            sb.append(ALL);
            return new ObjectName(sb.toString());
        }
        catch (javax.management.MalformedObjectNameException e) {
            // this should never occur
            return null;
        }
    }

    public static ObjectName getStatelessSessionBean(String p_Domain, String p_module, String p_Server, String p_Application
        , String p_Name) {
        try {
            StringBuffer sb = new StringBuffer(p_Domain);
            sb.append(":j2eeType=StatelessSessionBean");
            sb.append(",name=");
            sb.append(p_Name);
            sb.append(",EJBModule=");
            sb.append(p_module);
            sb.append(",J2EEApplication=");
            if ((p_Application != null) && (p_Application.length() > 0)) {
                sb.append(p_Application);
            }
            else {
                sb.append(NONE);
            }
            sb.append(",J2EEServer=");
            sb.append(p_Server);
            return new ObjectName(sb.toString());
        }
        catch (javax.management.MalformedObjectNameException e) {
            // this should never occur
            return null;
        }
    }

    public static ObjectName getStatelessSessionBeans(String p_Domain, String p_module) {
        try {
            StringBuffer sb = new StringBuffer(p_Domain);
            sb.append(":j2eeType=StatelessSessionBean");
            sb.append(",EJBModule=");
            sb.append(p_module);
            sb.append(",");
            sb.append(ALL);
            return new ObjectName(sb.toString());
        }
        catch (javax.management.MalformedObjectNameException e) {
            // this should never occur
            return null;
        }
    }

    public static ObjectName getStatelessSessionBeans(String p_Domain, String p_module, String p_Server) {
        try {
            StringBuffer sb = new StringBuffer(p_Domain);
            sb.append(":j2eeType=StatelessSessionBean");
            sb.append(",EJBModule=");
            sb.append(p_module);
            sb.append(",J2EEServer=");
            sb.append(p_Server);
            sb.append(",");
            sb.append(ALL);
            return new ObjectName(sb.toString());
        }
        catch (javax.management.MalformedObjectNameException e) {
            // this should never occur
            return null;
        }
    }

    public static ObjectName getMessageDrivenBean(String p_Domain, String p_module, String p_Server, String p_Application
        , String p_Name) {
        try {
            StringBuffer sb = new StringBuffer(p_Domain);
            sb.append(":j2eeType=MessageDrivenBean");
            sb.append(",name=");
            sb.append(p_Name);
            sb.append(",EJBModule=");
            sb.append(p_module);
            sb.append(",J2EEApplication=");
            if ((p_Application != null) && (p_Application.length() > 0)) {
                sb.append(p_Application);
            }
            else {
                sb.append(NONE);
            }
            sb.append(",J2EEServer=");
            sb.append(p_Server);
            return new ObjectName(sb.toString());
        }
        catch (javax.management.MalformedObjectNameException e) {
            // this should never occur
            return null;
        }
    }

    public static ObjectName getMessageDrivenBeans(String p_Domain, String p_module, String p_Server) {
        try {
            StringBuffer sb = new StringBuffer(p_Domain);
            sb.append(":j2eeType=MessageDrivenBean");
            sb.append(",EJBModule=");
            sb.append(p_module);
            sb.append(",J2EEServer=");
            sb.append(p_Server);
            sb.append(",");
            sb.append(ALL);
            return new ObjectName(sb.toString());
        }
        catch (javax.management.MalformedObjectNameException e) {
            // this should never occur
            return null;
        }
    }

    public static ObjectName getMessageDrivenBeans(String p_Domain, String p_module) {
        try {
            StringBuffer sb = new StringBuffer(p_Domain);
            sb.append(":j2eeType=MessageDrivenBean");
            sb.append(",EJBModule=");
            sb.append(p_module);
            sb.append(",");
            sb.append(ALL);
            return new ObjectName(sb.toString());
        }
        catch (javax.management.MalformedObjectNameException e) {
            // this should never occur
            return null;
        }
    }

    public static ObjectName JavaMailResource(String p_Domain, String p_Name, String p_Server
        , String p_Type) {
        try {
            StringBuffer sb = new StringBuffer(p_Domain);
            sb.append(":j2eeType=JavaMailResource");
            sb.append(",name=");
            sb.append(p_Name);
            sb.append(",J2EEServer=");
            sb.append(p_Server);
            sb.append(",type=");
            sb.append(p_Type);
            return new ObjectName(sb.toString());
        }
        catch (javax.management.MalformedObjectNameException e) {
            // this should never occur
            return null;
        }
    }

    public static ObjectName JavaMailResources(String p_Domain, String p_Server, String p_Type) {
        try {
            StringBuffer sb = new StringBuffer(p_Domain);
            sb.append(":j2eeType=JavaMailResource");
            sb.append(",");
            sb.append(ALL);
            sb.append(",J2EEServer=");
            sb.append(p_Server);
            sb.append(",type=");
            sb.append(p_Type);
            return new ObjectName(sb.toString());
        }
        catch (javax.management.MalformedObjectNameException e) {
            // this should never occur
            return null;
        }
    }

    public static ObjectName JNDIResource(String p_Domain, String p_Name, String p_Server) {
        try {
            StringBuffer sb = new StringBuffer(p_Domain);
            sb.append(":j2eeType=JNDIResource");
            sb.append(",name=");
            sb.append(p_Name);
            sb.append(",J2EEServer=");
            sb.append(p_Server);
            return new ObjectName(sb.toString());
        }
        catch (javax.management.MalformedObjectNameException e) {
            // this should never occur
            return null;
        }
    }

    public static ObjectName getWebModules() {
        try {
            return new ObjectName("*:j2eeType=WebModule,*");
        }
        catch (javax.management.MalformedObjectNameException e) {
            // this should never occur
            return null;
        }
    }

    public static ObjectName getWebModules(String p_Domain) {
        try {
            return new ObjectName(p_Domain + ":j2eeType=WebModule,*");
        }
        catch (javax.management.MalformedObjectNameException e) {
            // this should never occur
            return null;
        }
    }

    public static ObjectName getWebModules(String p_Domain, String p_Server) {
        try {
            StringBuffer sb = new StringBuffer(p_Domain);
            sb.append(":j2eeType=WebModule");
            if ((p_Server != null) && (p_Server.length() > 0)) {
                sb.append(",J2EEServer=");
                sb.append(p_Server);
            }
            sb.append(",*");
            return new ObjectName(sb.toString());
        }
        catch (javax.management.MalformedObjectNameException e) {
            // this should never occur
            return null;
        }
    }

    public static ObjectName getWebModules(String p_Domain, String p_Server, String p_Application) {
        try {
            StringBuffer sb = new StringBuffer(p_Domain);
            sb.append(":j2eeType=WebModule");
            if ((p_Server != null) && (p_Server.length() > 0)) {
                sb.append(",J2EEServer=");
                sb.append(p_Server);
            }
            if ((p_Application != null) && (p_Application.length() > 0)) {
                sb.append(",J2EEApplication=");
                sb.append(p_Application);
            }
            sb.append(",*");
            return new ObjectName(sb.toString());
        }
        catch (javax.management.MalformedObjectNameException e) {
            // this should never occur
            return null;
        }
    }

    public static ObjectName getWebModule(String p_Domain, String p_Server, String p_Application
        , String p_Name) {
        try {
            StringBuffer sb = new StringBuffer(p_Domain);
            sb.append(":j2eeType=WebModule");
            sb.append(",name=");
            sb.append(p_Name);
            sb.append(",J2EEServer=");
            sb.append(p_Server);
            sb.append(",J2EEApplication=");
            if ((p_Application != null) && (p_Application.length() > 0)) {
                sb.append(p_Application);
            }
            else {
                sb.append(NONE);
            }

            return new ObjectName(sb.toString());
        }
        catch (javax.management.MalformedObjectNameException e) {
            // this should never occur
            return null;
        }
    }

    public static ObjectName getResourceAdapterModule(String p_Domain, String p_Server, String p_Application
        , String p_Name) {
        try {
            StringBuffer sb = new StringBuffer(p_Domain);
            sb.append(":j2eeType=ResourceAdapterModule");
            sb.append(",name=");
            sb.append(p_Name);
            sb.append(",J2EEServer=");
            sb.append(p_Server);
            sb.append(",J2EEApplication=");
            if ((p_Application == null) || (p_Application.length() == 0)) {
                sb.append(NONE);
            } else {
                sb.append(p_Application);
            }
            return new ObjectName(sb.toString());
        }
        catch (javax.management.MalformedObjectNameException e) {
            // this should never occur
            return null;
        }
    }
  
    public static ObjectName getResourceAdapterModules(String p_Domain, String p_Server) {
        try {
            StringBuffer sb = new StringBuffer(p_Domain);
            sb.append(":j2eeType=ResourceAdapterModule");
            if ((p_Server != null) && (p_Server.length() > 0)) {
                sb.append(",J2EEServer=");
                sb.append(p_Server);
            }
            sb.append(",");
            sb.append(ALL);
            return new ObjectName(sb.toString());
        }
        catch (javax.management.MalformedObjectNameException e) {
            // this should never occur
            return null;
        }
    }

    public static ObjectName getResourceAdapterModules(String p_Domain, String p_Server, String p_Application) {
        try {
            StringBuffer sb = new StringBuffer(p_Domain);
            sb.append(":j2eeType=ResourceAdapterModule");
            if ((p_Server != null) && (p_Server.length() > 0)) {
                sb.append(",J2EEServer=");
                sb.append(p_Server);
            }
            if ((p_Application != null) && (p_Application.length() > 0)) {
                sb.append(",J2EEApplication=");
                sb.append(p_Application);
            }
            sb.append(",");
            sb.append(ALL);
            return new ObjectName(sb.toString());
        }
        catch (javax.management.MalformedObjectNameException e) {
            // this should never occur
            return null;
        }
    }

    public static ObjectName getResourceAdapter(String p_Domain, String p_ResourceAdapterModule, String p_Application, String p_Server, String p_Name) {
        try {
            StringBuffer sb = new StringBuffer(p_Domain);
            sb.append(":j2eeType=ResourceAdapter");
            sb.append(",name=");
            sb.append(p_Name);
            sb.append(",ResourceAdapterModule=");
            sb.append(p_ResourceAdapterModule);
            sb.append(",J2EEApplication=");
            if ((p_Application == null) || (p_Application.length() == 0)) {
                sb.append(NONE);
            } else {
                sb.append(p_Application);
            }
            sb.append(",J2EEServer=");
            sb.append(p_Server);
            return new ObjectName(sb.toString());
        }
        catch (javax.management.MalformedObjectNameException e) {
            // this should never occur
            return null;
        }
    }
 
    public static ObjectName getJCAResource(String p_Domain, String p_Server, String p_ResourceAdapter, String p_Name) {
        try {
            StringBuffer sb = new StringBuffer(p_Domain);
            sb.append(":j2eeType=JCAResource");
            sb.append(",name=");
            sb.append(p_Name);
            sb.append(",J2EEServer=");
            sb.append(p_Server);
            sb.append(",ResourceAdapter=");
            sb.append(p_ResourceAdapter);
            return new ObjectName(sb.toString());
        }
        catch (javax.management.MalformedObjectNameException e) {
            // this should never occur
            return null;
        }
    }
 
    public static ObjectName getJCAActivationSpec(String p_Domain, String p_JCAResource, String p_Server, String p_Name) {
        try {
            StringBuffer sb = new StringBuffer(p_Domain);
            sb.append(":j2eeType=JCAActivationSpec");
            sb.append(",name=");
            sb.append(p_Name);
            sb.append(",JCAResource=");
            sb.append(p_JCAResource);
            sb.append(",J2EEServer=");
            sb.append(p_Server);
            return new ObjectName(sb.toString());
        }
        catch (javax.management.MalformedObjectNameException e) {
            // this should never occur
            return null;
        }
    } 
 
    public static ObjectName getJCAAdminObject(String p_Domain, String p_JCAResource, String p_Server, String p_Name) {
        try {
            StringBuffer sb = new StringBuffer(p_Domain);
            sb.append(":j2eeType=JCAAdminObject");
            sb.append(",name=");
            sb.append(p_Name);
            sb.append(",JCAResource=");
            sb.append(p_JCAResource);
            sb.append(",J2EEServer=");
            sb.append(p_Server);
            return new ObjectName(sb.toString());
        }
        catch (javax.management.MalformedObjectNameException e) {
            // this should never occur
            return null;
        }
    } 
 
    public static ObjectName getJCAConnectionFactory(String p_Domain, String p_JCAResource, String p_Server, String p_Name) {
        try {
            StringBuffer sb = new StringBuffer(p_Domain);
            sb.append(":j2eeType=JCAConnectionFactory");
            sb.append(",name=");
            sb.append(p_Name);
            sb.append(",JCAResource=");
            sb.append(p_JCAResource);
            sb.append(",J2EEServer=");
            sb.append(p_Server);
            return new ObjectName(sb.toString());
        }
        catch (javax.management.MalformedObjectNameException e) {
            // this should never occur
            return null;
        }
    } 
 
    public static ObjectName getJCAManagedConnectionFactory(String p_Domain, String p_Server, String p_Name) {
        try {
            StringBuffer sb = new StringBuffer(p_Domain);
            sb.append(":j2eeType=JCAManagedConnectionFactory");
            sb.append(",name=");
            sb.append(p_Name);
            sb.append(",J2EEServer=");
            sb.append(p_Server);
            return new ObjectName(sb.toString());
        }
        catch (javax.management.MalformedObjectNameException e) {
            // this should never occur
            return null;
        }
    } 
 
    public static ObjectName ManagementListener(String p_Domain, String p_Server) {
        try {
            StringBuffer sb = new StringBuffer(p_Domain);
            sb.append(":type=management,name=managementListener");
            sb.append(",J2EEServer=");
            sb.append(p_Server);
            return new ObjectName(sb.toString());
        }
        catch (javax.management.MalformedObjectNameException e) {
            // this should never occur
            return null;
        }
    }

	public static ObjectName JTAResource(String p_Domain, String p_Server, String p_Name) {
		try {
			StringBuffer sb = new StringBuffer(p_Domain);
			sb.append(":j2eeType=JTAResource");
			sb.append(",name=");
			sb.append(p_Name);
			sb.append(",J2EEServer=");
			sb.append(p_Server);
			return new ObjectName(sb.toString());
		}
		catch (javax.management.MalformedObjectNameException e) {
			// this should never occur
			return null;
		}
	}

	public static ObjectName JDBCResource(String p_Domain, String p_Server, String p_Name) {
		try {
			StringBuffer sb = new StringBuffer(p_Domain);
			sb.append(":j2eeType=JDBCResource");
			sb.append(",name=");
			sb.append(p_Name);
			sb.append(",J2EEServer=");
			sb.append(p_Server);
			return new ObjectName(sb.toString());
		}
		catch (javax.management.MalformedObjectNameException e) {
			// this should never occur
			return null;
		}
	}
	public static ObjectName getJDBCDataSource(String p_Domain, String p_JDBCResource, String p_Server, String p_Name) {
		try {
			StringBuffer sb = new StringBuffer(p_Domain);
			sb.append(":j2eeType=JDBCDataSource");
			sb.append(",name=");
			sb.append(p_Name);
			sb.append(",JDBCResource=");
			sb.append(p_JDBCResource);
			sb.append(",J2EEServer=");
			sb.append(p_Server);
			return new ObjectName(sb.toString());
		}
		catch (javax.management.MalformedObjectNameException e) {
			// this should never occur
			return null;
		}
	} 
 
    public static ObjectName JDBCDataSources(String p_Domain, String p_Server) {
        try {
            StringBuffer sb = new StringBuffer(p_Domain);
            sb.append(":j2eeType=JDBCDataSource");
            sb.append(",J2EEServer=");
            sb.append(p_Server);
            sb.append(",");
            sb.append(ALL);
            return new ObjectName(sb.toString());
        }
        catch (javax.management.MalformedObjectNameException e) {
            // this should never occur
            return null;
        }
    } 
 
    public static ObjectName JDBCDataSources(String p_Domain, String p_JDBCResource, String p_Server) {
        try {
            StringBuffer sb = new StringBuffer(p_Domain);
            sb.append(":j2eeType=JDBCDataSource");
            sb.append(",JDBCResource=");
            sb.append(p_JDBCResource);
            sb.append(",J2EEServer=");
            sb.append(p_Server);
            sb.append(",");
            sb.append(ALL);
            return new ObjectName(sb.toString());
        }
        catch (javax.management.MalformedObjectNameException e) {
            // this should never occur
            return null;
        }
    } 
 
	public static ObjectName getJDBCDriver(String p_Domain, String p_Server, String p_Name) {
		try {
			StringBuffer sb = new StringBuffer(p_Domain);
			sb.append(":j2eeType=JDBCDriver");
			sb.append(",name=");
			sb.append(p_Name);
			sb.append(",J2EEServer=");
			sb.append(p_Server);
			return new ObjectName(sb.toString());
		}
		catch (javax.management.MalformedObjectNameException e) {
			// this should never occur
			return null;
		}
	} 
 
}
