/*
 * JOnAS: Java(TM) Open Application Server
 * Copyright (C) 1999 Bull S.A.
 * Contact: jonas-team@objectweb.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: JonasObjectName.java,v 1.30 2004/03/25 15:58:19 sauthieg Exp $
 * --------------------------------------------------------------------------
 */

package org.objectweb.jonas.jmx;

import javax.management.ObjectName;

import org.objectweb.jonas.service.ServiceManager;

/**
 * A set of static classes used to build the names of MBeans used in JOnAS
 * Each MBean or MBean type should have a method here.
 * @author Bruno Michel and Guillaume Riviere
 * Contributor(s):
 * Florent Benoit & Ludovic Bert : Ear service/Web Container service/Mail service
 * Miroslav Halas for Jetty
 * 03/03/24 Adriana Danes: Change Miro's wwwService method to return an ObjectName with type=webContainer and name=Jetty
 */
public class JonasObjectName {

    private static String domain = null;

    /**
     * @return Returns the domain name of the JOnAS server.
     */
    private static String getDomain() {
        if (domain == null) {
            try {
                domain = ((JmxService) ServiceManager.getInstance().getJmxService()).getJmxServer().getDefaultDomain();
            } catch (Exception e) {
                // should never occurs
            }
        }
        return domain;
    }
    
    /**
     * Create ObjectName for the JMX Connector Server which is an MBean inside the target MBeanServer
     */
    public static ObjectName jmxConnectorServer(String protocol, String connectorName) {
        try {
            return new ObjectName("connectors:protocol=" + protocol + ",name=" + connectorName);
        }
        catch (javax.management.MalformedObjectNameException e) {
            // this should never occur
            return null;
        }
    }

    public static ObjectName serverConfig() {
        try {
            return new ObjectName(getDomain() + ":type=management,name=reconfigManager");
        }
        catch (javax.management.MalformedObjectNameException e) {
            // this should never occur
            return null;
        }
    }

    public static ObjectName wwwService() {
        try {
            return new ObjectName(getDomain() + ":type=webContainer,name=Jetty");
        }
        catch (javax.management.MalformedObjectNameException e) {
            // this should never occur
            return null;
        }
    }

    public static ObjectName ejbService() {
        try {
            return new ObjectName(getDomain() + ":type=service,name=ejbContainers");
        }
        catch (javax.management.MalformedObjectNameException e) {
            // this should never occur
            return null;
        }
    }

    /**
     * Return the earService (Jmx).
     * @return the Ear service.
     */
    public static ObjectName earService() {
        try {
            return new ObjectName(getDomain() + ":type=service,name=ear");
        }
        catch (javax.management.MalformedObjectNameException e) {
            // this should never occur
            return null;
        }
    }

    /**
     * Return the mailService (Jmx).
     * @return the Mail service.
     */
    public static ObjectName mailService() {
        try {
            return new ObjectName(getDomain() + ":type=service,name=mail");
        }
        catch (javax.management.MalformedObjectNameException e) {
            // this should never occur
            return null;
        }
    }

    /**
     * Return the webContainerService (Jmx).
     * @return the web container service.
     */
    public static ObjectName webContainerService() {
        try {
            return new ObjectName(getDomain() + ":type=service,name=webContainers");
        }
        catch (javax.management.MalformedObjectNameException e) {
            // this should never occur
            return null;
        }
    }

    public static ObjectName databaseService() {
        try {
            return new ObjectName(getDomain() + ":type=service,name=database");
        }
        catch (javax.management.MalformedObjectNameException e) {
            // this should never occur
            return null;
        }
    }

    public static ObjectName resourceService() {
        try {
            return new ObjectName(getDomain() + ":type=service,name=resource");
        }
        catch (javax.management.MalformedObjectNameException e) {
            // this should never occur
            return null;
        }
    }

    public static ObjectName transactionService() {
        try {
            return new ObjectName(getDomain() + ":type=service,name=jtm");
        }
        catch (javax.management.MalformedObjectNameException e) {
            // this should never occur
            return null;
        }
    }

    public static ObjectName logService(String filename) {
        try {
            return new ObjectName(getDomain() + ":type=service,name=log,fname="
                + fileNameForObjectName(filename));
        }
        catch (javax.management.MalformedObjectNameException e) {
            // this should never occur
            return null;
        }
    }

    public static ObjectName allLogServices() {
        try {
            return new ObjectName(getDomain() + ":type=service,name=log,*");
        }
        catch (javax.management.MalformedObjectNameException e) {
            // this should never occur
            return null;
        }
    }

    public static ObjectName allServices() {
        try {
            return new ObjectName(getDomain() + ":type=service,*");
        }
        catch (javax.management.MalformedObjectNameException e) {
            // this should never occur
            return null;
        }
    }

    public static ObjectName jmsService() {
        try {
            return new ObjectName(getDomain() + ":type=service,name=jms");
        }
        catch (javax.management.MalformedObjectNameException e) {
            // this should never occur
            return null;
        }
    }

    public static ObjectName securityService() {
        try {
            return new ObjectName(getDomain() + ":type=service,name=security");
        }
        catch (javax.management.MalformedObjectNameException e) {
            // this should never occur
            return null;
        }
    }

    public static ObjectName jmxService() {
        try {
            return new ObjectName("JMImplementation:type=MBeanServerDelegate");
        }
        catch (javax.management.MalformedObjectNameException e) {
            // this should never occur
            return null;
        }
    }

    public static ObjectName www(String subtype)
        throws javax.management.MalformedObjectNameException {
        return new ObjectName(getDomain() + ":type=www,subtype=" + subtype);
    }

    public static ObjectName rar(String filename)
        throws javax.management.MalformedObjectNameException {
        return new ObjectName(getDomain() + ":type=resource,fname=" + fileNameForObjectName(filename));
    }

    public static ObjectName war(String filename)
        throws javax.management.MalformedObjectNameException {
        return new ObjectName(getDomain() + ":type=war,fname=" + fileNameForObjectName(filename));
    }

    public static ObjectName datasource(String name)
        throws javax.management.MalformedObjectNameException {
        return new ObjectName(getDomain() + ":type=datasource,name=" + name);
    }

    /**
     * Return an objectName for a Session type mail factory.
     * @param name the name of the mail factory
     * @return an objectName for the mail factory.
     * @throws javax.management.MalformedObjectNameException if the objectname can't be build
     */
    public static ObjectName sessionMailFactory(String name)
        throws javax.management.MalformedObjectNameException {
        return new ObjectName(getDomain() + ":type=sessionmailfactory,name=" + name);
    }

    /**
     * Return an objectName for a MimePartDataSource type mail factory.
     * @param name the name of the mail factory
     * @return an objectName for the mail factory.
     * @throws javax.management.MalformedObjectNameException if the objectname can't be build
     */
    public static ObjectName mimeMailFactory(String name)
        throws javax.management.MalformedObjectNameException {
        return new ObjectName(getDomain() + ":type=mimemailfactory,name=" + name);
    }

    /**
     * Return an objectName for a Security memory factory.
     * @param name the name of the security memory factory
     * @return an objectName for the security memory factory.
     * @throws javax.management.MalformedObjectNameException if the objectname can't be build
     */
    public static ObjectName securityMemoryFactory(String name)
        throws javax.management.MalformedObjectNameException {
        return new ObjectName(getDomain() + ":type=securityfactory,subtype=memory,name=" + name);
    }

    /**
     * Return an objectName for a Security datasource factory.
     * @param name the name of the security datasource factory
     * @return an objectName for the security datasource factory.
     * @throws javax.management.MalformedObjectNameException if the objectname can't be build
     */
    public static ObjectName securityDatasourceFactory(String name)
        throws javax.management.MalformedObjectNameException {
        return new ObjectName(getDomain() + ":type=securityfactory,subtype=datasource,name=" + name);
    }

    /**
     * Return an objectName for a Security ldap factory.
     * @param name the name of the security ldap factory
     * @return an objectName for the security ldap factory.
     * @throws javax.management.MalformedObjectNameException if the objectname can't be build
     */
    public static ObjectName securityLdapFactory(String name)
        throws javax.management.MalformedObjectNameException {
        return new ObjectName(getDomain() + ":type=securityfactory,subtype=ldap,name=" + name);
    }

    /**
     * Return an objectName for a user
     * @param resource the name of the resource on which the user depends
     * @param username the name of the user
     * @return an objectName for the user MBean
     * @throws javax.management.MalformedObjectNameException if the objectname can't be build
     */
    public static ObjectName user(String resource, String username)
        throws javax.management.MalformedObjectNameException {
        return new ObjectName(getDomain() + ":type=security,subtype=users,resource=" + resource
            + ",name=" + username);
    }

    /**
     * Return an objectName for all the users
     * @return an objectName for all the users
     * @throws javax.management.MalformedObjectNameException if the objectname can't be build
     */
    public static ObjectName allUsers() {
        try {
            return new ObjectName(getDomain() + ":type=security,subtype=users,*");
        }
        catch (javax.management.MalformedObjectNameException e) {
            // this should never occur
            return null;
        }
    }

    /**
     * Return an objectName for a group
     * @param resource the name of the resource on which the group depends
     * @param groupname the name of the group
     * @return an objectName for the group MBean
     * @throws javax.management.MalformedObjectNameException if the objectname can't be build
     */
    public static ObjectName group(String resource, String groupname)
        throws javax.management.MalformedObjectNameException {
        return new ObjectName(getDomain() + ":type=security,subtype=groups,resource=" + resource
            + ",name=" + groupname);
    }

    /**
     * Return an objectName for all the groups
     * @return an objectName for all the groups
     * @throws javax.management.MalformedObjectNameException if the objectname can't be build
     */
    public static ObjectName allGroups() {
        try {
            return new ObjectName(getDomain() + ":type=security,subtype=groups,*");
        }
        catch (javax.management.MalformedObjectNameException e) {
            // this should never occur
            return null;
        }
    }

    /**
     * Return an objectName for a role
     * @param resource the name of the resource on which the role depends
     * @param rolename the name of the role
     * @return an objectName for the user MBean
     * @throws javax.management.MalformedObjectNameException if the objectname can't be build
     */
    public static ObjectName role(String resource, String rolename)
        throws javax.management.MalformedObjectNameException {
        return new ObjectName(getDomain() + ":type=security,subtype=roles,resource=" + resource
            + ",name=" + rolename);
    }

    /**
     * Return an objectName for all the roles
     * @return an objectName for all the roles
     * @throws javax.management.MalformedObjectNameException if the objectname can't be build
     */
    public static ObjectName allRoles() {
        try {
            return new ObjectName(getDomain() + ":type=security,subtype=roles,*");
        }
        catch (javax.management.MalformedObjectNameException e) {
            // this should never occur
            return null;
        }
    }

    public static ObjectName resourceAdapters()
        throws javax.management.MalformedObjectNameException {
        return new ObjectName(getDomain() + ":type=resourceadapter,*");
    }

    public static ObjectName resourceAdapter(String name)
        throws javax.management.MalformedObjectNameException {
        return new ObjectName(getDomain() + ":type=resourceadapter,name=" + name);
    }

    public static ObjectName rmiConnector() {
        try {
            return new ObjectName(getDomain() + ":type=connector,name=rmiconnector");
        }
        catch (javax.management.MalformedObjectNameException e) {
            // this should never occur
            return null;
        }
    }

    public static ObjectName allWWW() {
        try {
            return new ObjectName(getDomain() + ":type=service,name=www,*");
        }
        catch (javax.management.MalformedObjectNameException e) {
            // this should never occur
            return null;
        }
    }

    public static ObjectName allEars() {
        try {
            return new ObjectName(getDomain() + ":type=ear,*");
        }
        catch (javax.management.MalformedObjectNameException e) {
            // this should never occur
            return null;
        }
    }

    public static ObjectName allRars() {
        try {
            return new ObjectName(getDomain() + ":type=resource,*");
        }
        catch (javax.management.MalformedObjectNameException e) {
            // this should never occur
            return null;
        }
    }

    public static ObjectName allWars() {
        try {
            return new ObjectName(getDomain() + ":type=war,*");
        }
        catch (javax.management.MalformedObjectNameException e) {
            // this should never occur
            return null;
        }
    }

    public static ObjectName allDatasources() {
        try {
            return new ObjectName(getDomain() + ":type=datasource,*");
        }
        catch (javax.management.MalformedObjectNameException e) {
            // this should never occur
            return null;
        }
    }

    /**
     * Return an objectName specifying all the session mail factories.
     * @return an objectName referencing all session mail factories.
     */
    public static ObjectName allSessionMailFactories() {
        try {
            return new ObjectName(getDomain() + ":type=sessionmailfactory,*");
        }
        catch (javax.management.MalformedObjectNameException e) {
            // this should never occur
            return null;
        }
    }

    /**
     * Return an objectName specifying all the mime mail factories.
     * @return an objectName referencing all mime mail factories.
     */
    public static ObjectName allMimeMailFactories() {
        try {
            return new ObjectName(getDomain() + ":type=mimemailfactory,*");
        }
        catch (javax.management.MalformedObjectNameException e) {
            // this should never occur
            return null;
        }
    }

    public static ObjectName allResourceAdaptors() {
        try {
            return new ObjectName(getDomain() + ":type=resourceadapter,*");
        }
        catch (javax.management.MalformedObjectNameException e) {
            // this should never occur
            return null;
        }
    }

    public static String getType(ObjectName obj) {
        return obj.getKeyProperty("type");
    }

    public static String fileNameForObjectName(String fileName) {
        return fileName.replace(':', '|');
    }

    /**
     * Return an objectName for the Security factory name.
     *
     * @param p_Name The name of the wanted security factory
     * @return an objectName for the security factory name.
     * @throws javax.management.MalformedObjectNameException if the objectname can't be build
     */
    public static ObjectName securityFactories(String p_Name)
        throws javax.management.MalformedObjectNameException {
        return new ObjectName(JonasObjectName.getDomain() + ":type=securityfactory,name=" + p_Name);
    }

    /**
     * Return an objectName for the Security factory name.
     *
     * @return an objectName for the security factory name.
     * @throws javax.management.MalformedObjectNameException if the objectname can't be build
     */
    public static ObjectName allSecurityFactories()
        throws javax.management.MalformedObjectNameException {
        return new ObjectName(JonasObjectName.getDomain() + ":type=securityfactory,*");
    }

    /**
     * Return an objectName for all the Security memory factories.
     *
     * @return an objectName for all the security memory factories
     * @throws javax.management.MalformedObjectNameException if the objectname can't be build
     */
    public static ObjectName allSecurityMemoryFactories()
        throws javax.management.MalformedObjectNameException {
        return new ObjectName(JonasObjectName.getDomain() + ":type=securityfactory,subtype=memory,*");
    }

    /**
     * Return an objectName for all the Security datasource factories.
     *
     * @return an objectName for all the security datasource factories
     * @throws javax.management.MalformedObjectNameException if the objectname can't be build
     */
    public static ObjectName allSecurityDatasourceFactories()
        throws javax.management.MalformedObjectNameException {
        return new ObjectName(JonasObjectName.getDomain() + ":type=securityfactory,subtype=datasource,*");
    }

    /**
     * Return an objectName for all the Security ldap factories.
     *
     * @return an objectName for all the security ldap factories
     * @throws javax.management.MalformedObjectNameException if the objectname can't be build
     */
    public static ObjectName allSecurityLdapFactories()
        throws javax.management.MalformedObjectNameException {
        return new ObjectName(JonasObjectName.getDomain() + ":type=securityfactory,subtype=ldap,*");
    }

    /**
     * Return an objectName for all users in a resource.
     *
     * @param p_Resource the name of the resource on which the user depends
     * @return an objectName for the user MBean
     * @throws javax.management.MalformedObjectNameException if the objectname can't be build
     */
    public static ObjectName allUsers(String p_Resource)
        throws javax.management.MalformedObjectNameException {
        return new ObjectName(JonasObjectName.getDomain() + ":type=security,subtype=users,resource="
            + p_Resource + ",*");
    }

    /**
     * Return an objectName for all roles in a resource.
     *
     * @param p_Resource the name of the resource on which the role depends
     * @return an objectName for the user MBean
     * @throws javax.management.MalformedObjectNameException if the objectname can't be build
     */
    public static ObjectName allRoles(String p_Resource)
        throws javax.management.MalformedObjectNameException {
        return new ObjectName(JonasObjectName.getDomain() + ":type=security,subtype=roles,resource="
            + p_Resource + ",*");
    }

    /**
     * Return an objectName for all groups in a resource.
     *
     * @param p_Resource the name of the resource on which the group depends
     * @return an objectName for the user MBean
     * @throws javax.management.MalformedObjectNameException if the objectname can't be build
     */
    public static ObjectName allGroups(String p_Resource)
        throws javax.management.MalformedObjectNameException {
        return new ObjectName(JonasObjectName.getDomain() + ":type=security,subtype=groups,resource="
            + p_Resource + ",*");
    }

    /**
     * A different implementation should allow returning a logical name.
     * This String is used within the Exception messages when throwing a ManagementException.
         * This is done currently in the invoke method of ManagementReprImpl/Mx4jManagementReprImpl classes.
     * @return String representation of the ObjectName
     */
    public String toString() {
        return super.toString();
    }
}
