/*
 * JOnAS: Java(TM) Open Application Server
 * Copyright (C) 1999 Bull S.A.
 * Contact: jonas-team@objectweb.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: 
 * --------------------------------------------------------------------------
 */
package org.objectweb.jonas.management.j2eemanagement;

import java.util.List;
import java.util.ArrayList;
// JOnAS Log
import org.objectweb.jonas.common.Log;
// Monolog
import org.objectweb.util.monolog.api.Logger;
import org.objectweb.util.monolog.api.BasicLevel;

/**
 * Implements a managed object which represents a management domain.
 */
public class J2EEDomain extends J2EEManagedObject implements J2EEDomainMBean {

    // list of object names corresponding to the servers associated with this domain
    protected ArrayList servers = null;

    static private Logger logger = null;
  
    /**
     * MBean constructor
     * @param objectName object name of the managed object
     * @param stateManageable if true, this managed object implements J2EE State Management Model
     * @param statisticsProvider if true, this managed object implements the J2EE StatisticProvide Model
     * @param eventProvider  if true, this managed object implements the J2EE EventProvider Model
     */  
    public J2EEDomain(String objectName, boolean stateManageable, boolean statisticsProvider, boolean eventProvider) {
        super(objectName, stateManageable, statisticsProvider, eventProvider);
        servers = new ArrayList();
        logger = Log.getLogger("org.objectweb.jonas.management.j2eemanagement");
        if (logger.isLoggable(BasicLevel.DEBUG))
            logger.log(BasicLevel.DEBUG, "J2EEDomain managed object created. OBJECT_NAME = " + objectName);
    }

    /**
     * @return The list of object names corresponding to the servers associated with this domain
     */
    public List getServers() {
        synchronized (servers) {
            return new ArrayList(servers);
        }             
    }

    /**
     * Add an object name to the <code>servers</code> list.
     * @param serverName Object name of a J2EEServer managed object associated with this domain
     */
    public void addServer(String serverName) {
        synchronized (servers) {
            if (servers.contains(serverName) == true) {
                if (logger.isLoggable(BasicLevel.DEBUG)) {
                    logger.log(BasicLevel.DEBUG, "The object name: " + serverName + " is already in the servers list");
                }
            } else {
                servers.add(serverName);
            }
        }
    }

    /**
     * Remove an object name from the <code>servers</code> list.
     * @return Object name of a server associated with this domain
     */
    public String removeServer(String serverName) {
        synchronized (servers) {
            int index = servers.indexOf(serverName);
            if (index == -1) {
                // name not found
                return null;
            } else {
                return (String) servers.remove(index);
            }
        }
    }
}
