/*
 * JOnAS: Java(TM) Open Application Server
 * Copyright (C) 1999 Bull S.A.
 * Contact: jonas-team@objectweb.org
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id:
 * --------------------------------------------------------------------------
 */
package org.objectweb.jonas.mejb;

import java.net.MalformedURLException;
import java.rmi.RemoteException;
import java.util.Set;

import javax.ejb.SessionBean;
import javax.ejb.SessionContext;
import javax.management.Attribute;
import javax.management.AttributeList;
import javax.management.AttributeNotFoundException;
import javax.management.InstanceAlreadyExistsException;
import javax.management.InstanceNotFoundException;
import javax.management.IntrospectionException;
import javax.management.InvalidAttributeValueException;
import javax.management.MBeanException;
import javax.management.MBeanInfo;
import javax.management.MBeanServer;
import javax.management.MBeanServerConnection;
import javax.management.ObjectName;
import javax.management.QueryExp;
import javax.management.ReflectionException;
import javax.management.j2ee.ListenerRegistration;
import javax.management.remote.JMXConnector;
import javax.management.remote.JMXConnectorFactory;
import javax.management.remote.JMXServiceURL;

import org.objectweb.jonas.jmx.J2eeObjectName;
import org.objectweb.jonas.jmx.JmxService;
import org.objectweb.jonas.management.j2eemanagement.ManagementListener;
import org.objectweb.jonas.management.j2eemanagement.ManagementListenerMBean;
import org.objectweb.jonas.service.ServiceManager;

/**
 * This is the Management EJB implementation for JOnAS.
 * A MEJB instance is created and deployed at JOnAS start time.
 * It is registered in the ejb/mgmt naming subcontext.
 * 
 * The current implementation only allows access to managed resources from within
 * the current server.
 * 
 * @author Adriana Danes
 */ 

public class ManagementBean implements SessionBean {

    protected SessionContext sessionContext = null;

    // The current JOnAS server's MBean server
    MBeanServer jmxServer = null;

    // MBean server connection of the currently administered JOnAS server
    MBeanServerConnection jmxServerConnection = null;

    // The current server name
    String serverName = null;
    // The current domain name
    String domainName = null;
    // The remote NotificationListener proxy name
    String proxyName = "MEJB_listener";

    /*========================= ejbCreate methods ============================*/

    public void ejbCreate() {
        // Get the MBeanServer reference to allow local access
        JmxService jmxService = null;
        try {
            jmxService = (JmxService) ServiceManager.getInstance().getJmxService();
        } catch (Exception e) {
            // should bever occurs
        }
        jmxServer = jmxService.getJmxServer();
        serverName = jmxService.getServerName();
        domainName = jmxService.getDomainName();

        // Get the MBeanServerConnection reference to allow remote access
        // By default the administered server is the current server
        try {
            JMXServiceURL jmxServiceUrl = new JMXServiceURL("rmi", "localhost", 0, "/jndi/jrmpconnector");
            // The environment map, null in the case of the current server
            java.util.Map environment = null;
            // Environment map for a remote server
            // environment = new java.util.HashMap();        
            //environment.put(Context.INITIAL_CONTEXT_FACTORY, "com.sun.jndi.rmi.registry.RegistryContextFactory");
            //environment.put(Context.PROVIDER_URL, "rmi://host:port");
            //environment.put(Context.URL_PKG_PREFIXES, "org.objectweb.jonas.naming");
            JMXConnector connector = JMXConnectorFactory.newJMXConnector(jmxServiceUrl, environment);
            connector.connect(environment);
            jmxServerConnection = connector.getMBeanServerConnection();
        } catch (MalformedURLException e) {
            // TO DO
        } catch (java.io.IOException ioe) {
            // TO DO
        }
        
    }

    /*====================== javax.ejb.SessionBean implementation =================*/

    public void ejbActivate() {
        // Nothing to do when the MEJB is activated
    }
    public void ejbPassivate() {
        // Nothing to do when the MEJB is passivated
    } 
    public void ejbRemove() {
        // Nothing to do when the MEJB is removed
    }   
    /** 
     * Sets the associated session context.
     * @param sessionContext - A SessionContext interface for the instance.
     */
    public void setSessionContext(SessionContext sessionContext) {
        this.sessionContext = sessionContext;
    }
 
    /*========================= ManagementBean implementation ============================*/   
    /*=============== The management methods are invoked on the local MBeanServer ========*/

    public Object getAttribute(ObjectName name, String attribute) throws 
        MBeanException,
        AttributeNotFoundException,
        InstanceNotFoundException,
        ReflectionException,
        RemoteException {

        return jmxServer.getAttribute(name, attribute);

        // Call getAttribute on MBeanServerConnection
        /*
        try {
            jmxServerConnection.getAttribute(name, attribute);
        } catch (java.io.IOException ioe) {
            throw (RemoteException) ioe;
        }
        */
    }
    
    public AttributeList getAttributes(ObjectName name, String[] attributes) throws 
        InstanceNotFoundException,
        ReflectionException,
        RemoteException {
        
        return jmxServer.getAttributes(name, attributes);
    }

    public String getDefaultDomain() throws RemoteException {
        return jmxServer.getDefaultDomain();
    }

    public Integer getMBeanCount() throws RemoteException {
        return jmxServer.getMBeanCount();
    }

    public MBeanInfo getMBeanInfo(ObjectName name) throws
        IntrospectionException,
        InstanceNotFoundException,
        ReflectionException,
        RemoteException {

        return jmxServer.getMBeanInfo(name);
    }

    public Object invoke(ObjectName name, String operationName, Object[] params, String[] signature) throws 
        MBeanException,
        InstanceNotFoundException,
        ReflectionException,
        RemoteException { 

        return jmxServer.invoke(name, operationName, params, signature);
    }

    public boolean isRegistered(ObjectName name) throws RemoteException {
        return jmxServer.isRegistered(name);
    }

    public Set queryNames(ObjectName name, QueryExp query) throws RemoteException {
        return jmxServer.queryNames(name, query);
    }

    public void setAttribute(ObjectName name, Attribute attribute) throws 
        MBeanException,
        AttributeNotFoundException,
        InstanceNotFoundException,
        InvalidAttributeValueException,
        ReflectionException,
        RemoteException { 

        jmxServer.setAttribute(name, attribute);
    }

    public AttributeList setAttributes(ObjectName name, AttributeList attributes) throws 
        InstanceNotFoundException,
        ReflectionException,
        RemoteException { 

        return jmxServer.setAttributes(name, attributes);
    }

    /**
     * Returns the ListenerRegistration implementation object which allows the client to register 
     * a event notification listener.
     * This method also creates a MBean 
     * @return An instance of the class implementing the ListenerRegistration interface. 
     * <code>null</code> is returned if 
     */
    public ListenerRegistration getListenerRegistry() throws RemoteException {

        // Create and register the ManagemenentListener MBean if this is not already done
        ObjectName listener_on = J2eeObjectName.ManagementListener(domainName, serverName);
        boolean isRegisteredListener = jmxServer.isRegistered(listener_on);
        if (!isRegisteredListener) {
            ManagementListenerMBean listenerMBean = new ManagementListener(proxyName);
            try {
                jmxServer.registerMBean(listenerMBean, listener_on);
            } catch (InstanceAlreadyExistsException ae) {
                // Not possible as tested before
            } catch (Exception e) {
                // Could not register MBean -> the management bean can't handle notifications 
                throw new RemoteException("Can not return ListenerRegistration implementation");
            }
        }
        // Create ListenerRegistration object 
        return new ListenerRegistrationImpl(listener_on, proxyName);
    }
}
