/*
 * JOnAS: Java(TM) Open Application Server
 * Copyright (C) 1999 Bull S.A.
 * Contact: jonas-team@objectweb.org
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: HArrayPoolMonitor.java,v 1.2 2004/02/20 19:04:19 ehardesty Exp $
 * --------------------------------------------------------------------------
 */

package org.objectweb.jonas.resource.pool.lib;

import org.objectweb.jonas.common.Log;  
import org.objectweb.jonas.resource.pool.api.Pool;
import org.objectweb.util.monolog.api.Logger;
import org.objectweb.util.monolog.api.BasicLevel;

/**
 * Keeps pool as small as possible (after conn's has reached MaxAge)
 * @author Eric Hardesty
 * Contributor(s): 
 */
public class HArrayPoolMonitor extends Thread {

    protected Pool pool;
    protected Logger logger = null;

    public HArrayPoolMonitor(Pool _pool) {
        super("HArrayPoolMonitor");
        setDaemon(true);
        this.pool = _pool;
        logger = Log.getLogger(Log.JONAS_JCA_PREFIX);
    }

    public void run() {
        int val = 0;
        while (true) {
            try {
                sleep(60 * 1000); // 60 sec
                val++;
                pool.check4MaxAge();
                if (val == 10) {  // Validate every 10 minutes
                    val = 0;
                    pool.validateMCs();
                }
            } catch (NullPointerException e) {
                e.printStackTrace();
            } catch (Exception ex) {
                logger.log(BasicLevel.ERROR, ex.toString());
            }
        }
    }
}
