/*
 * JOnAS: Java(TM) Open Application Server
 * Copyright (C) 1999 Bull S.A.
 * Contact: jonas-team@objectweb.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 * --------------------------------------------------------------------------
 * $Id: JavaVm.java,v 1.5 2004/03/19 14:31:52 sauthieg Exp $
 * --------------------------------------------------------------------------
 */

package org.objectweb.jonas.server;

// Java imports
import org.objectweb.jonas.common.JProp;
import org.objectweb.jonas.common.Log;
import org.objectweb.jonas.management.j2eemanagement.J2EEManagedObject;
import org.objectweb.util.monolog.api.Logger;

/**
 * The Java Virtual Machine used by the JOnAS server.
 * @author Michel-Ange Anton
 */
public class JavaVm extends J2EEManagedObject {

// ------------------------------------------------------------- Private Constants

    private final static String JAVA_VERSION = "java.version";
    private final static String JAVA_VENDOR = "java.vendor";
    private final static String NODE_LOCAL = "localhost";

// ------------------------------------------------------------- Privates Variables

    private static Logger s_Logger = null;

// ------------------------------------------------------------- Properties

    /**
     * JVM version.
     */
    private String javaVersion = null;

    /**
     * JVM vendor.
     */
    private String javaVendor = null;

    /**
     * Node (machine) the JVM is running on.
     */
    private String node = null;

// ------------------------------------------------------------- Contructors

    public JavaVm(String p_ObjectName, JProp p_Props) {
        super(p_ObjectName);
        javaVersion = p_Props.getValue(JAVA_VERSION);
        javaVendor = p_Props.getValue(JAVA_VENDOR);
        try {
            java.net.InetAddress oInet = java.net.InetAddress.getLocalHost();
            node = oInet.getHostName();
        }
        catch (java.net.UnknownHostException e) {
            node = NODE_LOCAL;
        }
        // get a logger for server traces
        s_Logger = Log.getLogger(Log.JONAS_SERVER_PREFIX);
    }

// ------------------------------------------------------------- Properties Methods

    public String getJavaVersion() {
        return javaVersion;
    }

    public String getJavaVendor() {
        return javaVendor;
    }

    public String getNode() {
        return node;
    }

}
