/*
 * JOnAS: Java(TM) Open Application Server
 * Copyright (C) 1999 Bull S.A.
 * Contact: jonas-team@objectweb.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * Initial developer(s): Christophe Ney
 * Contributor(s): Lutris Tecnologies Inc.
 *
 * --------------------------------------------------------------------------
 * $Id: MessageDrivenJMS2_1Desc.java,v 1.3 2004/03/19 14:31:48 sauthieg Exp $
 * --------------------------------------------------------------------------
 */

package org.objectweb.jonas_ejb.deployment.api;

import java.util.ListIterator;

import org.objectweb.jonas_ejb.deployment.xml.ActivationConfig;
import org.objectweb.jonas_ejb.deployment.xml.ActivationConfigProperty;
import org.objectweb.jonas_ejb.deployment.xml.AssemblyDescriptor;
import org.objectweb.jonas_ejb.deployment.xml.JonasMessageDriven;
import org.objectweb.jonas_ejb.deployment.xml.MessageDriven;
import org.objectweb.jonas_lib.deployment.api.DeploymentDescException;
import org.objectweb.jonas_lib.deployment.xml.JLinkedList;
/**
 * Class to hold meta-information related to a message driven bean
 * @author Philippe Coq
 */
public class MessageDrivenJMS2_1Desc extends MessageDrivenDesc {



    protected MessageDriven messageDriven = null;

    /**
     * package protected constructor used by API
     */
    MessageDrivenJMS2_1Desc(ClassLoader classLoader,  
                            MessageDriven md, 
                            AssemblyDescriptor asd, 
                            JonasMessageDriven jMd, 
                            String fileName)
            throws DeploymentDescException {
        super(classLoader, md,  asd, jMd, fileName);
        messageDriven = md;
        ActivationConfig ac = md.getActivationConfig();
        if( ac != null) {
            JLinkedList acpl = md.getActivationConfig().getActivationConfigPropertyList();
            for (ListIterator lit = acpl.listIterator();lit.hasNext();) {
                ActivationConfigProperty el = (ActivationConfigProperty)lit.next();
                if (el.getActivationConfigPropertyName().equals("destinationType")) {
                    if (el.getActivationConfigPropertyValue().equals("javax.jms.Queue")) {
                        destinationType = javax.jms.Queue.class;
                    } else if (el.getActivationConfigPropertyValue().equals("javax.jms.Topic")) {
                        destinationType = javax.jms.Topic.class;
                        isTopicDestination = true;
                    } else {
                        throw new DeploymentDescException("destinationType value for ejb-name "+ejbName);
                    } 
                } else if (el.getActivationConfigPropertyName().equals("messageSelector")) {
                    selector = el.getActivationConfigPropertyValue();
                }
                else if (el.getActivationConfigPropertyName().equals("acknowledgeMode")) {
                    if (el.getActivationConfigPropertyValue().equals("Auto-acknowledge")) {
                    acknowledgeMode = AUTO_ACKNOWLEDGE;
                    } else  if (el.getActivationConfigPropertyValue().equals("Dups-ok-acknowledge")) {
                        acknowledgeMode = DUPS_OK_ACKNOWLEDGE;
                }
                } else if (el.getActivationConfigPropertyName().equals("subscriptionDurability")) {
                    if (el.getActivationConfigPropertyValue().equals("Durable")) {
                        subscriptionDurability = SUBS_DURABLE;
                    } else {
                        subscriptionDurability = SUBS_NON_DURABLE;
                    }
                } else {
//                    throw new Error("Incorrect activation-config for message-driven bean "+ejbName);
                }
            }
        } else {
            throw new Error("No destination specified for message-driven bean "+ejbName);
        }

    }

    /**
     * @return the MessageDriven object
     */
    public MessageDriven getMessageDriven() {
        return messageDriven;
    }

}

