/**
 * JOnAS: Java(TM) Open Application Server
 * Copyright (C) 1999 Bull S.A. 
 * Contact: jonas-team@objectweb.org
 * 
 * This library is free software; you can redistribute it and/or
 *
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or 1any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * Initial developer: JOnAS team
 * --------------------------------------------------------------------------
 * $Id: MessageDriven.java,v 1.7 2004/03/19 14:31:47 sauthieg Exp $
 * --------------------------------------------------------------------------
 */
package org.objectweb.jonas_ejb.deployment.xml;

/** 
 * This class defines the implementation of the element message-driven
 * 
 * @author JOnAS team
 */

public class MessageDriven extends CommonEjb {

    /**
     * ejb-name
     */ 
    private String ejbName = null;

    /**
     * ejb-class
     */ 
    private String ejbClass = null;

    /**
     * messaging-type 
     * specifies the message listener interface of the message driven bean
     * if not specified it is assumed to be javax.jms.MessageListener
     */ 
    private String messagingType = "javax.jms.MessageListener";


    /**
     * transaction-type
     */ 
    private String transactionType = null;

    /**
     * message-selector (EJB2.0 only)
     */ 
    private String messageSelector = null;

    /**
     * acknowledge-mode (EJB2.0 only)
     */ 
    private String acknowledgeMode = null;

    /**
     * message-driven-destination (EJB2.0 only)
     */ 
    private MessageDrivenDestination messageDrivenDestination = null;

    /**
     * message-destination-type (EJB2.1 only)
     */ 
    private String messageDestinationType = null;

    /**
     * message-destination-link (EJB2.1 only)
     */ 
    private String messageDestinationLink = null;

    /**
     * activation-config (EJB2.1 only)
     */ 
    private ActivationConfig  activationConfig = null;

    /**
     * security-identity
     */ 
    private SecurityIdentity securityIdentity = null;

    /**
     * Constructor
     */
    public MessageDriven() {
        super();
    }

    /** 
     * Gets the ejb-name
     * @return the ejb-name
     */
    public String getEjbName() {
        return ejbName;
    }

    /** 
     * Set the ejb-name
     * @param ejbName ejbName
     */
    public void setEjbName(String ejbName) {
        this.ejbName = ejbName;
    }

    /** 
     * Gets the ejb-class
     * @return the ejb-class
     */
    public String getEjbClass() {
        return ejbClass;
    }

    /** 
     * Set the ejb-class
     * @param ejbClass ejbClass
     */
    public void setEjbClass(String ejbClass) {
        this.ejbClass = ejbClass;
    }


    /** 
     * Gets the messaging-type
     * @return the messaging-type
     */
    public String getMessagingType() {
        return messagingType;
    }

    /** 
     * Set the messaging-type
     * @param MessagingType messaging-type
     */
    public void setMessagingType(String messagingType) {
        this.messagingType = messagingType;
    }

    /** 
     * Gets the transaction-type
     * @return the transaction-type
     */
    public String getTransactionType() {
        return transactionType;
    }

    /** 
     * Set the transaction-type
     * @param transactionType transactionType
     */
    public void setTransactionType(String transactionType) {
        this.transactionType = transactionType;
    }

    /** 
     * Gets the message-selector (EJB2.0 only)
     * @return the message-selector
     */
    public String getMessageSelector() {
        return messageSelector;
    }

    /** 
     * Set the message-selector (EJB2.0 only)
     * @param messageSelector messageSelector
     */
    public void setMessageSelector(String messageSelector) {
        this.messageSelector = messageSelector;
    }

    /** 
     * Gets the acknowledge-mode (EJB2.0 only)
     * @return the acknowledge-mode
     */
    public String getAcknowledgeMode() {
        return acknowledgeMode;
    }

    /** 
     * Set the acknowledge-mode (EJB2.0 only)
     * @param acknowledgeMode acknowledgeMode
     */
    public void setAcknowledgeMode(String acknowledgeMode) {
        this.acknowledgeMode = acknowledgeMode;
    }

    /** 
     * Gets the message-driven-destination (EJB2.0 only)
     * @return the message-driven-destination
     */
    public MessageDrivenDestination getMessageDrivenDestination() {
        return messageDrivenDestination;
    }

    /** 
     * Set the message-driven-destination  (EJB2.0 only)
     * @param messageDrivenDestination messageDrivenDestination
     */
    public void setMessageDrivenDestination(MessageDrivenDestination messageDrivenDestination) {
        this.messageDrivenDestination = messageDrivenDestination;
    }

    /** 
     * Gets the message-destination-type (EJB2.1 only)
     * @return the message-destination-type
     */
    public String getMessageDestinationType() {
        return messageDestinationType;
    }

    /** 
     * Set the message-destination-type (EJB2.1 only)
     * @param messageDestinationType message-destination-type
     */
    public void setMessageDestinationType(String messageDestinationType) {
        this.messageDestinationType = messageDestinationType;
    }



    /** 
     * Gets the message-destination-link (EJB2.1 only)
     * @return the message-destination-link
     */
    public String getMessageDestinationLink() {
        return messageDestinationLink;
    }

    /** 
     * Set the message-destination-link (EJB2.1 only)
     * @param messageDestinationLink message-destination-link
     */
    public void setMessageDestinationLink(String messageDestinationLink) {
        this.messageDestinationLink = messageDestinationLink;
    }

    /** 
     * Gets the activation-config (EJB2.1 only)
     * @return the activation-config
     */
    public ActivationConfig getActivationConfig() {
        return activationConfig;
    }

    /** 
     * Set the activation-config (EJB2.1 only)
     * @param activationConfig activation-config
     */
    public void setActivationConfig(ActivationConfig activationConfig) {
        this.activationConfig = activationConfig;
    }

    /** 
     * Gets the security-identity
     * @return the security-identity
     */
    public SecurityIdentity getSecurityIdentity() {
        return securityIdentity;
    }

    /** 
     * Set the security-identity
     * @param securityIdentity securityIdentity
     */
    public void setSecurityIdentity(SecurityIdentity securityIdentity) {
        this.securityIdentity = securityIdentity;
    }



    /**
     * Represents this element by it's XML description.
     * @param indent use this indent for prexifing XML representation.
     * @return the XML description of this object.
     */
    public String toXML(int indent) {
        StringBuffer sb = new StringBuffer();
        sb.append(indent(indent));
        sb.append("<message-driven>\n");

        indent += 2;

         // description
        sb.append(xmlElement(getDescription(), "description", indent));
        // display-name
        sb.append(xmlElement(getDisplayName(), "display-name", indent));
        // small-icon
        sb.append(xmlElement(getIcon().getSmallIcon(), "small-icon", indent));
        // large-icon
        sb.append(xmlElement(getIcon().getLargeIcon(), "large-icon", indent));
        // ejb-name
        sb.append(xmlElement(ejbName, "ejb-name", indent));
        // ejb-class
        sb.append(xmlElement(ejbClass, "ejb-class", indent));
        // transaction-type
        sb.append(xmlElement(transactionType, "transaction-type", indent));

        /* the old EJB2.0
        // message-selector
        sb.append(xmlElement(messageSelector, "message-selector", indent));
        // acknowledge-mode
        sb.append(xmlElement(acknowledgeMode, "acknowledge-mode", indent));
        // message-driven-destination
        if(messageDrivenDestination != null) {
            sb.append(messageDrivenDestination.toXML(indent));
        }
        */

        // message-destination-type (EJB2.1 only)
        sb.append(xmlElement(messageDestinationType, "message-destination-type",indent));
        // message-destination-link  (EJB2.1 only)
        sb.append(xmlElement(messageDestinationLink, "message-destination-link",indent));
        // activation-config (EJB2.1 only)
        if(activationConfig != null) {
            sb.append(activationConfig.toXML(indent));
        }

        // env-entry
        sb.append(getEnvEntryList().toXML(indent));
        // ejb-ref
        sb.append(getEjbRefList().toXML(indent));
        // ejb-local-ref
        sb.append(getEjbLocalRefList().toXML(indent));
        // security-identity
        if(securityIdentity != null) {
            sb.append(securityIdentity.toXML(indent));
        }
        // resource-ref
        sb.append(getResourceRefList().toXML(indent));
        // resource-env-ref
        sb.append(getResourceEnvRefList().toXML(indent));
        // service-ref
        sb.append(getServiceRefList().toXML(indent));
        indent -= 2;
        sb.append(indent(indent));
        sb.append("</message-driven>\n");

        return sb.toString();
    }
}
