/*
 * JOnAS: Java(TM) Open Application Server
 * Copyright (C) 1999 Bull S.A.
 * Contact: jonas-team@objectweb.org
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or 1any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * Initial developer: Florent BENOIT
 * --------------------------------------------------------------------------
 * $Id: JonasServiceRef.java,v 1.1 2003/10/27 14:48:15 benoitf Exp $
 * --------------------------------------------------------------------------
 */

package org.objectweb.jonas_lib.deployment.xml;

/**
 * This class defines the implementation of the element jonas-service-ref.
 * @author Florent Benoit
 */
public class JonasServiceRef extends AbsElement {

    /**
     * Name of this jonas-service-ref
     */
    private String serviceRefName = null;

    /**
     * jndi name of this jonas-ejb-ref
     */
    private String jndiName = null;

    /**
     * List of init parameters
     */
    private JLinkedList jonasInitParamList = null;

    
    /**
     * Constructor : build a new JonasServiceRef object
     */
    public JonasServiceRef() {
        jonasInitParamList = new JLinkedList("jonas-init-param");
    }



    // Setters

    /**
     * Sets the name
     * @param serviceRefName the name to use
     */
    public void setServiceRefName(String serviceRefName) {
        this.serviceRefName = serviceRefName;
    }


    /**
     * Sets the jndi name
     * @param jndiName the jndi-name to use
     */
    public void setJndiName(String jndiName) {
        this.jndiName = jndiName;
    }

    /**
     * Add a parameter
     * @param jonasInitParam the JonasInitParam object to add to our list
     */
    public void addJonasInitParam(JonasInitParam jonasInitParam) {
        jonasInitParamList.add(jonasInitParam);
    }



    // Getters


    /**
     * @return the name of the service-ref
     */
    public String getServiceRefName() {
        return serviceRefName;
    }


    /**
     * @return the jndi-name of the service-ref
     */
    public String getJndiName() {
        return jndiName;
    }


    /**
     * @return the list of init parameters
     */
    public JLinkedList getJonasInitParamList() {
        return jonasInitParamList;
    }




    /**
     * Represents this element by it's XML description.
     * @param indent use this indent for prexifing XML representation.
     * @return the XML description of this object.
     */
    public String toXML(int indent) {
        StringBuffer sb = new StringBuffer();
        sb.append(indent(indent));
        sb.append("<jonas-service-ref>\n");

        indent += 2;

        // name
        sb.append(xmlElement(serviceRefName, "service-ref-name", indent));

        // jndi-name
        sb.append(xmlElement(jndiName, "jndi-name", indent));

        // init parameters
        sb.append(jonasInitParamList.toXML(indent));

        indent -= 2;
        sb.append(indent(indent));
        sb.append("</jonas-service-ref>\n");
        return sb.toString();
    }


}
