/**
 * JOnAS: Java(TM) Open Application Server
 * Copyright (C) 1999 Bull S.A.
 * Contact: jonas-team@objectweb.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * Initial developer(s): Guillaume SAUTHIER
 * --------------------------------------------------------------------------
 * $Id: DirLocator.java,v 1.2 2004/03/19 14:31:54 sauthieg Exp $
 * --------------------------------------------------------------------------
 */
package org.objectweb.jonas_lib.loader.locator;

import java.io.File;
import java.io.IOException;
import java.net.URL;
import java.util.List;
import java.util.Vector;

/**
 * A <code>DirLocator</code> is used to look up for a file 
 * inside a directory. 
 *
 * @author Guillaume Sauthier
 */
public class DirLocator extends Locator {

    private File file = null;

    public DirLocator(URL jar) throws IOException {
        String filename = jar.getFile();
        file = new File(filename);
    }

    /**
     * Returns true when file was found.
     *
     * @param path the path to the file to look up
     *
     * @return true when file was found, otherwise false.
     */
    public boolean hasFile(String path) {

        File child = new File(file, path);
        return (child.exists() && child.isFile());
    }

    /**
     * Returns true when directory was found.
     *
     * @param path the path to the directory to look up
     *
     * @return true when directory was found, otherwise false.
     */
    public boolean hasDirectory(String path) {

        File child = new File(file, path);
        return (child.exists() && child.isDirectory());
    }

    /**
     * Returns a list of filename stored in path.
     *
     * @param path the path to the directory where looking for files
     *
     * @return a list of filename stored in path.
     */
    public List listContent(String path) {

        File child = new File(file, path);
        List libs = new Vector();
        // List directory content
        if (child.isDirectory()) {
            addContent(child, libs);
        }
        
        return libs;
    }

    /**
     * Add only files in the given List
     * recursive!
     */
    private void addContent(File f, List l) {
        File[] childs = f.listFiles();
        if (childs != null) {
            for (int i = 0; i < childs.length; i++) {
                if (childs[i].isDirectory()) {
                    addContent(childs[i], l);
                } else if (childs[i].isFile()) {
                    l.add(childs[i].getPath().substring(file.getPath().length()));
                }
            }
        }
    }

}
