/*
 * JOnAS: Java(TM) Open Application Server
 * Copyright (C) 2004 Bull S.A.
 * Contact: jonas-team@objectweb.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * Initial developer: Florent BENOIT
 * --------------------------------------------------------------------------
 * $Id: AbsPermissionManager.java,v 1.2 2004/03/18 14:29:38 benoitf Exp $
 * --------------------------------------------------------------------------
 */

package org.objectweb.jonas_lib.security;

import java.security.Policy;

import javax.security.jacc.PolicyConfiguration;
import javax.security.jacc.PolicyConfigurationFactory;
import javax.security.jacc.PolicyContextException;

/**
 * Defines an abstract PermissionManager class
 * which will manage JACC permissions for an ejbjar, webapp, etc.
 * @author Florent Benoit
 */
public abstract class AbsPermissionManager {

    /**
     * JACC Policy configuration
     */
    protected PolicyConfiguration policyConfiguration = null;

    /**
     * Context ID
     */
    protected String contextId = null;


    /**
     * Policy to use
     */
    protected static Policy policy = null;


    /**
     * Default Constructor
     * @param contextId context ID used for PolicyContext
     * @throws PermissionManagerException if permissions can't be set
     */
    public AbsPermissionManager(String contextId)  throws PermissionManagerException {
        this.contextId = contextId;

        PolicyConfigurationFactory policyConfigurationFactory = null;
        // Init JACC
        try {
            policyConfigurationFactory = PolicyConfigurationFactory.getPolicyConfigurationFactory();
        } catch (Exception e) {
            throw new PermissionManagerException("Error when trying to get the PolicyConfigurationFactory object : '" + e.getMessage() + "'.");
        }
        try {
            this.policyConfiguration = policyConfigurationFactory.getPolicyConfiguration(contextId, true);
        } catch (PolicyContextException pce) {
            throw new PermissionManagerException("Error when trying to get the PolicyConfiguration object with contextId '"
                                                 + contextId + "' : " + pce.getMessage());
        }

        // Policy to use
        policy = Policy.getPolicy();

    }


    /**
     * Delete this object
     */
    public void delete() throws PermissionManagerException {
        resetDeploymentDesc();

        try {
            policyConfiguration.delete();
        } catch (PolicyContextException pce) {
            throw new PermissionManagerException("Can't delete policyConfiguration object", pce);
        }
        policyConfiguration = null;
        policy.refresh();
    }

    /**
     * Commit the Policy Configuration
     * @throws PermissionManagerException if commit can't be done
     */
    public void commit() throws PermissionManagerException {
        try {
            policyConfiguration.commit();
            policy.refresh();
        } catch (PolicyContextException pce) {
            throw new PermissionManagerException("Can't commit configuration", pce);
        }
    }


    /**
     * Reset Deployment Descriptor
     */
    protected abstract void resetDeploymentDesc();
}
