/*
 * JOnAS: Java(TM) Open Application Server
 * Copyright (C) 1999 Bull S.A.
 * Contact: jonas-team@objectweb.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * Initial Developer : Sauthier Guillaume
 * --------------------------------------------------------------------------
 * $Id: JaxRpcPortComponentDesc.java,v 1.6 2004/03/26 08:57:04 sauthieg Exp $
 * --------------------------------------------------------------------------
 */
package org.objectweb.jonas_ws.deployment.api;

import org.objectweb.jonas_web.deployment.api.WebContainerDeploymentDesc;
import org.objectweb.jonas_ws.deployment.xml.PortComponent;


public class JaxRpcPortComponentDesc extends PortComponentDesc {

    /** If the PortComponent is linked to a servlet */
    private WebContainerDeploymentDesc webDesc = null;

    public JaxRpcPortComponentDesc(ClassLoader cl,
                                   PortComponent pc,
                                   ServiceDesc parent) 
        throws WSDeploymentDescException {

        super(cl, pc, parent);

        // set ServiceImplBean link from servlet-link element
        sibLink = pc.getServiceImplBean().getServletLink();
    }

    /**
     * Return true if the Service Impl Bean is an EJB.
     *
     * @return true if the Service Impl Bean is an EJB.
     */
    public boolean hasBeanImpl() {
        return false;
    }

    /**
     * Return true if the Service Impl Bean is a JaxRpc component.
     *
     * @return true if the Service Impl Bean is a JaxRpc component.
     */
    public boolean hasJaxRpcImpl() {
        return true;
    }


    /**
     * Return the WebContainerDeploymentDesc object linked with this
     * portComponentDesc
     *
     * @return the WebContainerDeploymentDesc object linked with this
     *         portComponentDesc
     */
    public WebContainerDeploymentDesc getWebDesc() {
        return webDesc;
    }

    /**
     * Set the webDesc for this endpoint.
     *
     * @param web The web DD declaring the JaxRpc Endpoint.
     */
    public void setWebDesc(WebContainerDeploymentDesc web) {
        webDesc = web;
        sib = web.getServletClassname(sibLink);
    }


    /**
     * Setter method for J2EE component linking.
     * @param desc the descriptor of the component implementing the endpoint.
     * @throws WSDeploymentDescException when desc is an unknown type.
     */
    public void setDesc(Object desc) throws WSDeploymentDescException {
        if (desc instanceof WebContainerDeploymentDesc) {
            setWebDesc((WebContainerDeploymentDesc) desc);
        } else {
            throw new WSDeploymentDescException("for a JaxRpc endpoint, setDesc must take a "
                                                + WebContainerDeploymentDesc.class.getName() 
                                                + "param.");
        }
    }

    public String toString() {
        StringBuffer sb = new StringBuffer();
        
        sb.append(super.toString());
        sb.append("\ngetWebDesc()=" + getWebDesc());
        
        return sb.toString();
    }
}
