/*
 * JOnAS : Java(TM) OpenSource Application Server
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * Initial Developer : Guillaume Sauthier
 * --------------------------------------------------------------------------
 * $Id: WsClientDDModifier.java,v 1.1 2004/01/21 15:26:57 sauthieg Exp $
 * --------------------------------------------------------------------------
*/

package org.objectweb.jonas_ws.wsgen.ddmodifier;

import org.objectweb.jonas_ws.wsgen.utils.XMLUtils;

import org.w3c.dom.Document;
import org.w3c.dom.Element;

import java.lang.String;


/**
 * Modify a Web Services Client Deployment Desc Element. Wrapper around a
 * <code>jonas-service-ref</code> element
 *
 * @author Guillaume Sauthier
 */
public class WsClientDDModifier extends DeploymentDescModifier {

    /** XML Element names */
    private static final String JONAS_INIT_PARAM = "jonas-init-param";
    private static final String PARAM_NAME = "param-name";
    private static final String PARAM_VALUE = "param-value";

    /**
     * Creates a new WsClientDDModifier where element is a
     * <code>jonas-service-ref</code> XML Node.
     *
     * @param name service-ref-name value
     * @param doc document base for Element creation
     * @param base base element for searching jonas-service-ref
     */
    public WsClientDDModifier(String name, Document doc, Element base) {
        super(XMLUtils.getJonasServiceRef(base, name), doc);
    }

    /**
     * Add a jonas-init-param in jonas-service-ref.
     *
     * @param name param name
     * @param value param value
     */
    public void addJonasInitParam(String name, String value) {
        Element jip = newJOnASElement(JONAS_INIT_PARAM);
        Element pn = newJOnASElement(PARAM_NAME, name);
        Element pv = newJOnASElement(PARAM_VALUE, value);

        jip.appendChild(pn);
        jip.appendChild(pv);

        element.appendChild(jip);
    }
}
