/*
 * JOnAS: Java(TM) Open Application Server
 * Copyright (C) 1999 Bull S.A.
 * Contact: jonas-team@objectweb.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * Initial developer(s): Xavier Delplanque
 * --------------------------------------------------------------------------
 * $Id: VcPortComponent.java,v 1.3 2004/03/19 14:31:49 sauthieg Exp $
 * --------------------------------------------------------------------------
 */

package org.objectweb.jonas_ws.wsgen.generator.axis;

import java.util.Iterator;
import java.util.List;
import java.util.Vector;

import org.objectweb.jonas_lib.deployment.api.HandlerDesc;
import org.objectweb.jonas_ws.deployment.api.PortComponentDesc;
import org.objectweb.jonas_ws.deployment.api.SSBPortComponentDesc;

/**
 * Member of a VelocityContext. Contains information about a PortComponent(Desc/Ref).
 *
 * @author Xavier Delplanque
 */
public class VcPortComponent {

    /** port component name */
    private String name;

    /** the sib if the endpoint is an ejb */
    private VcBean bean;
 
    /** a string containing sei method names separated by ',' */
    private static final String SEP = ",";

    /** a list of method names */
    private String methods;
 
    /** port component handlers */
    private Vector handlers = new Vector();

    /** the JAXRPC class name if the sib is a servlet */
    private String jaxRpcClassName;

    /** the wsdl file to display when ?wsdl is used */
    private String wsdlFilename;


    /**
     * Construct a VcPortComponent from a PortComponentDesc.
     * used for server-side configuration files generation.
     * (server-config.wsdd)
     */
    public VcPortComponent(PortComponentDesc pcd, String wsdl) {

        // set name
        name = pcd.getName();

        wsdlFilename = wsdl;

        // set bean or jaxRpcClassName
        if (pcd.hasBeanImpl()) {
            // set bean
            bean = new VcBean(((SSBPortComponentDesc) pcd).getSessionStatelessDesc());
        }
        else if (pcd.hasJaxRpcImpl()) {
            // set jaxRpcClassName
            jaxRpcClassName = pcd.getSIBClassname();
        }	    

        // set methods
        String sei = pcd.getServiceEndpointInterface();
        methods = "*";
        /*
          Method[] ms = sei.getMethods();
          methods = "";
          for (int i = 0; i < ms.length; i++){
          methods += ms[i].getName();
          if (i != ms.length){
          methods +=SEP;
          }
          }
        */

        // set handlers
        List hs = pcd.getHandlers();	
        for (Iterator itH = hs.iterator(); itH.hasNext();) {
            HandlerDesc hd = (HandlerDesc) itH.next();
            handlers.add(new VcHandler(hd));
        }
		
    }

    /**
     * Construct a VcPortComponent from a PortComponentRef.
     * used for client-side configuration files generation.
     * (client-config.wsdd)
     */
    public VcPortComponent(String name, List hrs) {

        // set name
        this.name = name;

        // set handlers
        for (Iterator itH = hrs.iterator(); itH.hasNext();) {
            HandlerDesc hr = (HandlerDesc) itH.next();
            handlers.add(new VcHandler(hr));
        }
		
    }
 
    public String getName() {
        return name;
    }
 
    public VcBean getBean() {
        return bean;
    }

    public String getWSDLFilename() {
        return wsdlFilename;
    }
 
    public String getMethods() {
        return methods;
    }
 
    public Vector getHandlers() {
        return handlers;
    }
 
    public String getJaxRpcClassName() {
        return jaxRpcClassName;
    }
}
