/*
 * JOnAS: Java(TM) Open Application Server
 * Copyright (C) 1999 Bull S.A.
 * Contact: jonas-team@objectweb.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * Initial developer(s): Sauthier Guillaume
 * --------------------------------------------------------------------------
 * $Id: VcTypeMapping.java,v 1.2 2004/02/16 12:16:42 sauthieg Exp $
 * --------------------------------------------------------------------------
 */

package org.objectweb.jonas_ws.wsgen.generator.axis;

import javax.xml.namespace.QName;

/**
 * Member of a VelocityContext. Contains information used
 * to create a typeMapping WSDD tag.
 *
 * @author Guillaume SAUTHIER
 */
public abstract class VcTypeMapping {

    /** classname */
    private String classname;

    /** xml type QName */
    private QName xmlType;

    private static final String ENCODING_STYLE = 
        "http://schemas.xmlsoap.org/soap/encoding/";

    /**
     * Create a VcTypeMapping holding typeMapping information.
     */
    public VcTypeMapping(QName xml, String name) {
        classname = name;
        xmlType = xml;
    }

    public String getClassname() {
        return classname;
    }

    public String getNamespaceURI() {
        return xmlType.getNamespaceURI();
    }

    public String getLocalPart() {
        return xmlType.getLocalPart();
    }

    protected abstract String getSerializerFactory();

    protected abstract String getDeserializerFactory();

    public String toString() {
        StringBuffer sb = new StringBuffer();
        sb.append("<typeMapping xmlns:ns=\"" + getNamespaceURI() + "\"\n");
        sb.append("             qname=\"ns:" + getLocalPart() + "\"\n");
        sb.append("             languageSpecificType=\"java:" + getClassname() + "\"\n");
        sb.append("             serializer=\"" + getSerializerFactory() + "\"\n");
        sb.append("             deserializer=\"" + getDeserializerFactory() + "\" />");
        return sb.toString();
    }
}
