/*
 * JOnAS : Java(TM) OpenSource Application Server
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * Initial Developer : Guillaume Sauthier
 * --------------------------------------------------------------------------
 * $Id: WebAppModifier.java,v 1.4 2004/03/25 15:38:44 sauthieg Exp $
 * --------------------------------------------------------------------------
 */

package org.objectweb.jonas_ws.wsgen.modifier;

import java.io.File;
import java.util.Iterator;
import java.util.List;

import org.objectweb.jonas_ws.deployment.api.PortComponentDesc;
import org.objectweb.jonas_ws.deployment.api.ServiceDesc;
import org.objectweb.jonas_ws.deployment.api.ServiceRefDesc;
import org.objectweb.jonas_ws.wsgen.WsGenException;
import org.objectweb.jonas_ws.wsgen.archive.Archive;
import org.objectweb.jonas_ws.wsgen.archive.WebApp;
import org.objectweb.jonas_ws.wsgen.ddmodifier.WsClientDDModifier;
import org.objectweb.jonas_ws.wsgen.ddmodifier.WsEndpointDDModifier;
import org.objectweb.jonas_ws.wsgen.generator.Generator;
import org.objectweb.jonas_ws.wsgen.generator.GeneratorFactory;
import org.objectweb.util.monolog.api.BasicLevel;
import org.w3c.dom.Document;

/**
 * Modify a given WebApp.
 * 
 * @author Guillaume Sauthier
 */
public class WebAppModifier extends ArchiveModifier {

    /** webapp */
    private WebApp web;

    /**
     * Creates a new WebAppModifier
     * 
     * @param webapp
     *            the WebApp J2EE archive
     */
    public WebAppModifier(WebApp webapp) {
        super(webapp);
        web = webapp;
    }

    /**
     * Modify the current archive and return a modified archive.
     * 
     * @return a modified archive.
     * 
     * @throws WsGenException
     *             When modification fails
     */
    public Archive modify() throws WsGenException {
        
        logger.log(BasicLevel.INFO, "Processing WebApp " + web.getName());
        
        GeneratorFactory gf = GeneratorFactory.getInstance();
        Document jwebapp = web.getJonasWebAppDoc();
        Document webapp = web.getWebAppDoc();

        List refs = web.getServiceRefDescs();

        for (Iterator i = refs.iterator(); i.hasNext();) {
            ServiceRefDesc ref = (ServiceRefDesc) i.next();

            // create dd modifier
            WsClientDDModifier ddm = new WsClientDDModifier(ref
                    .getServiceRefName(), jwebapp, jwebapp.getDocumentElement());

            // launch generation
            Generator g = gf.newGenerator(ref, ddm, web);
            g.generate();
            g.compile();

            // add files in web archive
            g.addFiles(web);
        }

        // create dd modifier
        WsEndpointDDModifier ddm = new WsEndpointDDModifier(webapp);

        List sds = web.getServiceDescs();

        for (Iterator i = sds.iterator(); i.hasNext();) {
            ServiceDesc sd = (ServiceDesc) i.next();

            // launch generation
            Generator g = gf.newGenerator(sd, ddm);
            g.generate();
            g.compile();

            // add files in web archive
            g.addFiles(web);

            // we have to remove the servlets elements defined for ports
            for (Iterator p = sd.getPortComponents().iterator(); p.hasNext();) {
                PortComponentDesc port = (PortComponentDesc) p.next();
                //ddm.removeServlet(port.getSibLink());
            }
        }

        return save(gf.getConfiguration(), "webapps" + File.separator
                + web.getName());
    }
}
